% Auto-generated chapter 59 for bukhari
% Hadiths in this chapter: 131

\hadithdefcmd{bukhari}{3190}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ جَامِعِ بْنِ شَدَّادٍ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ قَالَ جَاءَ نَفَرٌ مِنْ بَنِي تَمِيمٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا بَنِي تَمِيمٍ، أَبْشِرُوا ‏"‏‏.‏ قَالُوا بَشَّرْتَنَا فَأَعْطِنَا‏.‏ فَتَغَيَّرَ وَجْهُهُ، فَجَاءَهُ أَهْلُ الْيَمَنِ، فَقَالَ ‏"‏ يَا أَهْلَ الْيَمَنِ، اقْبَلُوا الْبُشْرَى إِذْ لَمْ يَقْبَلْهَا بَنُو تَمِيمٍ ‏"‏‏.‏ قَالُوا قَبِلْنَا‏.‏ فَأَخَذَ النَّبِيُّ صلى الله عليه وسلم يُحَدِّثُ بَدْءَ الْخَلْقِ وَالْعَرْشِ، فَجَاءَ رَجُلٌ فَقَالَ يَا عِمْرَانُ، رَاحِلَتُكَ تَفَلَّتَتْ، لَيْتَنِي لَمْ أَقُمْ‏.‏\hadithno{3190}\hadithtrans{Narrated `Imran bin Husain:Some people of Bani Tamim came to the Prophet (ﷺ) and he said (to them), "O Bani Tamim! rejoice with glad tidings." They said, "You have given us glad tidings, now give us something." On hearing that the color of his face changed then the people of Yemen came to him and he said, "O people of Yemen ! Accept the good tidings, as Bani Tamim has refused them." The Yemenites said, "We accept them. Then the Prophet (ﷺ) started taking about the beginning of creation and about Allah's Throne. In the mean time a man came saying, "O `Imran! Your she-camel has run away!'' (I got up and went away), but I wish I had not left that place (for I missed what Allah's Messenger (ﷺ) had said}}
\hadithdefcmd{bukhari}{3191}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا جَامِعُ بْنُ شَدَّادٍ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، أَنَّهُ حَدَّثَهُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَعَقَلْتُ نَاقَتِي بِالْبَابِ، فَأَتَاهُ نَاسٌ مِنْ بَنِي تَمِيمٍ فَقَالَ ‏"‏ اقْبَلُوا الْبُشْرَى يَا بَنِي تَمِيمٍ ‏"‏‏.‏ قَالُوا قَدْ بَشَّرْتَنَا فَأَعْطِنَا‏.‏ مَرَّتَيْنِ، ثُمَّ دَخَلَ عَلَيْهِ نَاسٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ ‏"‏ اقْبَلُوا الْبُشْرَى يَا أَهْلَ الْيَمَنِ، إِذْ لَمْ يَقْبَلْهَا بَنُو تَمِيمٍ ‏"‏‏.‏ قَالُوا قَدْ قَبِلْنَا يَا رَسُولَ اللَّهِ، قَالُوا جِئْنَاكَ نَسْأَلُكَ عَنْ هَذَا الأَمْرِ قَالَ ‏"‏ كَانَ اللَّهُ وَلَمْ يَكُنْ شَىْءٌ غَيْرُهُ، وَكَانَ عَرْشُهُ عَلَى الْمَاءِ، وَكَتَبَ فِي الذِّكْرِ كُلَّ شَىْءٍ، وَخَلَقَ السَّمَوَاتِ وَالأَرْضَ ‏"‏‏.‏ فَنَادَى مُنَادٍ ذَهَبَتْ نَاقَتُكَ يَا ابْنَ الْحُصَيْنِ‏.‏ فَانْطَلَقْتُ فَإِذَا هِيَ يَقْطَعُ دُونَهَا السَّرَابُ، فَوَاللَّهِ لَوَدِدْتُ أَنِّي كُنْتُ تَرَكْتُهَا‏.‏\hadithno{3191}\hadithtrans{Narrated Imran bin Husain: I went to the Prophet (ﷺ) and tied my she-camel at the gate. The people of Bani Tamim came to the Prophet (ﷺ) who said "O Bani Tamim! Accept the good tidings." They said twice, 'You have given us the good tidings, now give us something" Then some Yemenites came to him and he said, "Accept the good tidings, O people of Yemen, for Bani Tamim refused them." They said, "We accept it, O Allah's Messenger (ﷺ)! We have come to ask you about this matter (i.e. the start of creations)." He said, "First of all, there was nothing but Allah, and (then He created His Throne). His throne was over the water, and He wrote everything in the Book (in the Heaven) and created the Heavens and the Earth." Then a man shouted, "O Ibn Husain! Your she-camel has gone away!" So, I went away and could not see the she-camel because of the mirage. By Allah, I wished I had left that she-camel (but not that gathering)}}
\hadithdefcmd{bukhari}{3192}{وَرَوَى عِيسَى، عَنْ رَقَبَةَ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ سَمِعْتُ عُمَرَ ـ رضى الله عنه ـ يَقُولُ قَامَ فِينَا النَّبِيُّ صلى الله عليه وسلم مَقَامًا، فَأَخْبَرَنَا عَنْ بَدْءِ الْخَلْقِ حَتَّى دَخَلَ أَهْلُ الْجَنَّةِ مَنَازِلَهُمْ، وَأَهْلُ النَّارِ مَنَازِلَهُمْ، حَفِظَ ذَلِكَ مَنْ حَفِظَهُ، وَنَسِيَهُ مَنْ نَسِيَهُ‏.‏\hadithno{3192}\hadithtrans{Narrated 'Umar:One day the Prophet (ﷺ) stood up amongst us for a long period and informed us about the beginning of creation (and talked about everything in detail) till he mentioned how the people of Paradise will enter their places and the people of Hell will enter their places. Some remembered what he had said, and some forgot it}}
\hadithdefcmd{bukhari}{3193}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، عَنْ أَبِي أَحْمَدَ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم أُرَاهُ ‏ "‏ يَقُولُ اللَّهُ شَتَمَنِي ابْنُ آدَمَ وَمَا يَنْبَغِي لَهُ أَنْ يَشْتِمَنِي، وَتَكَذَّبَنِي وَمَا يَنْبَغِي لَهُ، أَمَّا شَتْمُهُ فَقَوْلُهُ إِنَّ لِي وَلَدًا‏.‏ وَأَمَّا تَكْذِيبُهُ فَقَوْلُهُ لَيْسَ يُعِيدُنِي كَمَا بَدَأَنِي ‏"‏‏.‏\hadithno{3193}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah the Most Superior said, "The son of Adam slights Me, and he should not slight Me, and he disbelieves in Me, and he ought not to do so. As for his slighting Me, it is that he says that I have a son; and his disbelief in Me is his statement that I shall not recreate him as I have created (him) before}}
\hadithdefcmd{bukhari}{3194}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمَّا قَضَى اللَّهُ الْخَلْقَ كَتَبَ فِي كِتَابِهِ، فَهْوَ عِنْدَهُ فَوْقَ الْعَرْشِ إِنَّ رَحْمَتِي غَلَبَتْ غَضَبِي ‏"‏‏.‏\hadithno{3194}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When Allah completed the creation, He wrote in His Book which is with Him on His Throne, "My Mercy overpowers My Anger}}
\hadithdefcmd{bukhari}{3195}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا ابْنُ عُلَيَّةَ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، كَانَتْ بَيْنَهُ وَبَيْنَ أُنَاسٍ خُصُومَةٌ فِي أَرْضٍ، فَدَخَلَ عَلَى عَائِشَةَ فَذَكَرَ لَهَا ذَلِكَ، فَقَالَتْ يَا أَبَا سَلَمَةَ اجْتَنِبِ الأَرْضَ، فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ظَلَمَ قِيدَ شِبْرٍ طُوِّقَهُ مِنْ سَبْعِ أَرَضِينَ ‏"‏‏.‏\hadithno{3195}\hadithtrans{Narrated Muhammad bin Ibrahim bin Al-Harith:from Abu Salama bin `Abdur-Rahman who had a dispute with some people on a piece of land, and so he went to `Aisha and told her about it. She said, "O Abu Salama, avoid the land, for Allah's Messenger (ﷺ) said, 'Any person who takes even a span of land unjustly, his neck shall be encircled with it down seven earths}}
\hadithdefcmd{bukhari}{3196}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَخَذَ شَيْئًا مِنَ الأَرْضِ بِغَيْرِ حَقِّهِ خُسِفَ بِهِ يَوْمَ الْقِيَامَةِ إِلَى سَبْعِ أَرَضِينَ ‏"‏‏.‏\hadithno{3196}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) said, "Any person who takes a piece of land unjustly will sink down the seven earths on the Day of Resurrection}}
\hadithdefcmd{bukhari}{3197}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الزَّمَانُ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ، السَّنَةُ اثْنَا عَشَرَ شَهْرًا، مِنْهَا أَرْبَعَةٌ حُرُمٌ، ثَلاَثَةٌ مُتَوَالِيَاتٌ ذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ، وَرَجَبُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ ‏"‏‏.‏\hadithno{3197}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said. "(The division of time has turned to its original form which was current when Allah created the Heavens and the Earths. The year is of twelve months, out of which four months are sacred: Three are in succession Dhul-Qa' da, Dhul-Hijja and Muharram, and (the fourth is) Rajab of (the tribe of) Mudar which comes between Jumada-ath-Thaniyah and Sha`ban}}
\hadithdefcmd{bukhari}{3198}{حَدَّثَنِي عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، أَنَّهُ خَاصَمَتْهُ أَرْوَى فِي حَقٍّ زَعَمَتْ أَنَّهُ انْتَقَصَهُ لَهَا إِلَى مَرْوَانَ، فَقَالَ سَعِيدٌ أَنَا أَنْتَقِصُ مِنْ حَقِّهَا شَيْئًا، أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَخَذَ شِبْرًا مِنَ الأَرْضِ ظُلْمًا، فَإِنَّهُ يُطَوَّقُهُ يَوْمَ الْقِيَامَةِ مِنْ سَبْعِ أَرَضِينَ ‏"‏‏.‏ قَالَ ابْنُ أَبِي الزِّنَادِ عَنْ هِشَامٍ عَنْ أَبِيهِ قَالَ قَالَ لِي سَعِيدُ بْنُ زَيْدٍ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3198}\hadithtrans{Narrated Sa`id bin Zaid bin `Amr bin Nufail:That Arwa sued him before Marwan for a right, which she claimed, he had deprived her of. On that Sa`id said, "How should I deprive her of her right? I testify that I heard Allah's Messenger (ﷺ) saying, 'If anyone takes a span of land unjustly, his neck will be encircled with it down seven earths on the Day of Resurrection}}
\hadithdefcmd{bukhari}{3199}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَبِي ذَرٍّ حِينَ غَرَبَتِ الشَّمْسُ ‏"‏ تَدْرِي أَيْنَ تَذْهَبُ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ فَإِنَّهَا تَذْهَبُ حَتَّى تَسْجُدَ تَحْتَ الْعَرْشِ، فَتَسْتَأْذِنَ فَيُؤْذَنَ لَهَا، وَيُوشِكُ أَنْ تَسْجُدَ فَلاَ يُقْبَلَ مِنْهَا، وَتَسْتَأْذِنَ فَلاَ يُؤْذَنَ لَهَا، يُقَالُ لَهَا ارْجِعِي مِنْ حَيْثُ جِئْتِ‏.‏ فَتَطْلُعُ مِنْ مَغْرِبِهَا، فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏وَالشَّمْسُ تَجْرِي لِمُسْتَقَرٍّ لَهَا ذَلِكَ تَقْدِيرُ الْعَزِيزِ الْعَلِيمِ ‏\}‏‏"‏‏.‏\hadithno{3199}\hadithtrans{Narrated Abu Dhar:The Prophet (ﷺ) asked me at sunset, "Do you know where the sun goes (at the time of sunset)?" I replied, "Allah and His Apostle know better." He said, "It goes (i.e. travels) till it prostrates Itself underneath the Throne and takes the permission to rise again, and it is permitted and then (a time will come when) it will be about to prostrate itself but its prostration will not be accepted, and it will ask permission to go on its course but it will not be permitted, but it will be ordered to return whence it has come and so it will rise in the west. And that is the interpretation of the Statement of Allah: "And the sun Runs its fixed course For a term (decreed). that is The Decree of (Allah) The Exalted in Might, The All- Knowing}}
\hadithdefcmd{bukhari}{3200}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَبْدُ اللَّهِ الدَّانَاجُ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّمْسُ وَالْقَمَرُ مُكَوَّرَانِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{3200}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The sun and the moon will be folded up (deprived of their light) on the Day of Resurrection}}
\hadithdefcmd{bukhari}{3201}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ يُخْبِرُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏"‏‏.‏\hadithno{3201}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "The sun and the moon do not eclipse because of someone's death or life (i.e. birth), but they are two signs amongst the Signs of Allah. So, if you see them (i.e. eclipse) offer the (eclipse) prayer}}
\hadithdefcmd{bukhari}{3202}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ ‏"‏‏.‏\hadithno{3202}\hadithtrans{Narrated `Abdullah bin `Abbas:The Prophet (ﷺ) said, "The sun and the moon are two signs amongst the Signs of Allah. They do not eclipse because of someone's death or life. So, if you see them (i.e. eclipse), celebrate the Praises of Allah (i.e. pray)}}
\hadithdefcmd{bukhari}{3203}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ خَسَفَتِ الشَّمْسُ قَامَ فَكَبَّرَ وَقَرَأَ قِرَاءَةً طَوِيلَةً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ وَقَامَ كَمَا هُوَ، فَقَرَأَ قِرَاءَةً طَوِيلَةً وَهْىَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْىَ أَدْنَى مِنَ الرَّكْعَةِ الأُولَى، ثُمَّ سَجَدَ سُجُودًا طَوِيلاً، ثُمَّ فَعَلَ فِي الرَّكْعَةِ الآخِرَةِ مِثْلَ ذَلِكَ، ثُمَّ سَلَّمَ وَقَدْ تَجَلَّتِ الشَّمْسُ، فَخَطَبَ النَّاسَ، فَقَالَ فِي كُسُوفِ الشَّمْسِ وَالْقَمَرِ ‏"‏ إِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ، وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمُوهُمَا فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏‏.‏\hadithno{3203}\hadithtrans{Narrated `Aisha:On the day of a solar eclipse, Allah's Messenger (ﷺ) stood up (to offer the eclipse prayer). He recited Takbir, recited a long recitation (of Holy Verses), bowed a long bowing, and then he raised his head saying, "Allah hears him who sends his praises to Him." Then he stayed standing, recited a long recitation again, but shorter than the former, bowed a long bowing, but shorter than the first, performed a long prostration and then performed the second rak`a in the same way as he had done the first. By the time he had finished his prayer with Taslim, the solar eclipse had been over. Then he addressed the people referring to the solar and lunar eclipses saying, "These are two signs amongst the Signs of Allah, and they do not eclipse because of anyone's death or life. So, if you see them, hasten for the Prayer}}
\hadithdefcmd{bukhari}{3204}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنْ أَبِي مَسْعُودٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّمْسُ وَالْقَمَرُ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏"‏‏.‏\hadithno{3204}\hadithtrans{Narrated Abu Mas`ud:The Prophet (ﷺ) said, "the sun and the moon do not eclipse because of the death or life of someone, but they are two signs amongst the Signs of Allah. So, if you see them, offer the Prayer (of eclipse)}}
\hadithdefcmd{bukhari}{3205}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نُصِرْتُ بِالصَّبَا، وَأُهْلِكَتْ عَادٌ بِالدَّبُورِ ‏"‏‏.‏\hadithno{3205}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I have been made victorious with the Saba (i.e. easterly wind) and the people of 'Ad were destroyed with the Dabur (i.e. westerly wind)}}
\hadithdefcmd{bukhari}{3206}{حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا رَأَى مَخِيلَةً فِي السَّمَاءِ أَقْبَلَ وَأَدْبَرَ وَدَخَلَ وَخَرَجَ وَتَغَيَّرَ وَجْهُهُ، فَإِذَا أَمْطَرَتِ السَّمَاءُ سُرِّيَ عَنْهُ، فَعَرَّفَتْهُ عَائِشَةُ ذَلِكَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا أَدْرِي لَعَلَّهُ كَمَا قَالَ قَوْمٌ ‏\{‏فَلَمَّا رَأَوْهُ عَارِضًا مُسْتَقْبِلَ أَوْدِيَتِهِمْ‏\}‏ ‏"‏‏.‏ الآيَةَ‏.‏\hadithno{3206}\hadithtrans{Narrated Ata:`Aisha said If the Prophet (ﷺ) saw a cloud In the sky, he would walk to and fro in agitation, go out and come in, and the color of his face would change, and if it rained, he would feel relaxed." So `Aisha knew that state of his. So the Prophet (ﷺ) said, I don't know (am afraid), it may be similar to what happened to some people referred to in the Holy Qur'an in the following Verse: -- "Then when they saw it as a dense cloud coming towards their valleys, they said, 'This is a cloud bringing us rain!' Nay, but, it is that (torment) which you were asking to be hastened a wind wherein is severe torment}}
\hadithdefcmd{bukhari}{3207}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ،‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، وَهِشَامٌ، قَالاَ حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنْ مَالِكِ بْنِ صَعْصَعَةَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَيْنَا أَنَا عِنْدَ الْبَيْتِ بَيْنَ النَّائِمِ وَالْيَقْظَانِ ـ وَذَكَرَ بَيْنَ الرَّجُلَيْنِ ـ فَأُتِيتُ بِطَسْتٍ مِنْ ذَهَبٍ مُلِئَ حِكْمَةً وَإِيمَانًا، فَشُقَّ مِنَ النَّحْرِ إِلَى مَرَاقِّ الْبَطْنِ، ثُمَّ غُسِلَ الْبَطْنُ بِمَاءِ زَمْزَمَ، ثُمَّ مُلِئَ حِكْمَةً وَإِيمَانًا، وَأُتِيتُ بِدَابَّةٍ أَبْيَضَ دُونَ الْبَغْلِ وَفَوْقَ الْحِمَارِ الْبُرَاقُ، فَانْطَلَقْتُ مَعَ جِبْرِيلَ حَتَّى أَتَيْنَا السَّمَاءَ الدُّنْيَا قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قِيلَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ عَلَى آدَمَ، فَسَلَّمْتُ عَلَيْهِ، فَقَالَ مَرْحَبًا بِكَ مِنِ ابْنٍ وَنَبِيٍّ‏.‏ فَأَتَيْنَا السَّمَاءَ الثَّانِيَةَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ قِيلَ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ عَلَى عِيسَى وَيَحْيَى فَقَالاَ مَرْحَبًا بِكَ مِنْ أَخٍ وَنَبِيٍّ‏.‏ فَأَتَيْنَا السَّمَاءَ الثَّالِثَةَ، قِيلَ مَنْ هَذَا قِيلَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قِيلَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ يُوسُفَ فَسَلَّمْتُ عَلَيْهِ، قَالَ مَرْحَبًا بِكَ مِنْ أَخٍ وَنَبِيٍّ فَأَتَيْنَا السَّمَاءَ الرَّابِعَةَ، قِيلَ مَنْ هَذَا قِيلَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قِيلَ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قِيلَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ عَلَى إِدْرِيسَ فَسَلَّمْتُ عَلَيْهِ، فَقَالَ مَرْحَبًا مِنْ أَخٍ وَنَبِيٍّ‏.‏ فَأَتَيْنَا السَّمَاءَ الْخَامِسَةَ، قِيلَ مَنْ هَذَا قَالَ جِبْرِيلُ‏.‏ قِيلَ وَمَنْ مَعَكَ قِيلَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ قَالَ نَعَمْ‏.‏ قِيلَ مَرْحَبًا بِهِ، وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْنَا عَلَى هَارُونَ، فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَرْحَبًا بِكَ مِنْ أَخٍ وَنَبِيٍّ‏.‏ فَأَتَيْنَا عَلَى السَّمَاءِ السَّادِسَةِ، قِيلَ مَنْ هَذَا قِيلَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ مَرْحَبًا بِهِ، وَلَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ عَلَى مُوسَى، فَسَلَّمْتُ ‏\{‏عَلَيْهِ‏\}‏ فَقَالَ مَرْحَبًا بِكَ مِنْ أَخٍ وَنَبِيٍّ‏.‏ فَلَمَّا جَاوَزْتُ بَكَى‏.‏ فَقِيلَ مَا أَبْكَاكَ قَالَ يَا رَبِّ، هَذَا الْغُلاَمُ الَّذِي بُعِثَ بَعْدِي يَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِهِ أَفْضَلُ مِمَّا يَدْخُلُ مِنْ أُمَّتِي‏.‏ فَأَتَيْنَا السَّمَاءَ السَّابِعَةَ، قِيلَ مَنْ هَذَا قِيلَ جِبْرِيلُ‏.‏ قِيلَ مَنْ مَعَكَ قِيلَ مُحَمَّدٌ‏.‏ قِيلَ وَقَدْ أُرْسِلَ إِلَيْهِ مَرْحَبًا بِهِ، وَنِعْمَ الْمَجِيءُ جَاءَ‏.‏ فَأَتَيْتُ عَلَى إِبْرَاهِيمَ، فَسَلَّمْتُ عَلَيْهِ فَقَالَ مَرْحَبًا بِكَ مِنِ ابْنٍ وَنَبِيٍّ، فَرُفِعَ لِيَ الْبَيْتُ الْمَعْمُورُ، فَسَأَلْتُ جِبْرِيلَ فَقَالَ هَذَا الْبَيْتُ الْمَعْمُورُ يُصَلِّي فِيهِ كُلَّ يَوْمٍ سَبْعُونَ أَلْفَ مَلَكٍ، إِذَا خَرَجُوا لَمْ يَعُودُوا إِلَيْهِ آخِرَ مَا عَلَيْهِمْ، وَرُفِعَتْ لِي سِدْرَةُ الْمُنْتَهَى فَإِذَا نَبِقُهَا كَأَنَّهُ قِلاَلُ هَجَرٍ، وَوَرَقُهَا كَأَنَّهُ آذَانُ الْفُيُولِ، فِي أَصْلِهَا أَرْبَعَةُ أَنْهَارٍ نَهْرَانِ بَاطِنَانِ وَنَهْرَانِ ظَاهِرَانِ، فَسَأَلْتُ جِبْرِيلَ فَقَالَ أَمَّا الْبَاطِنَانِ فَفِي الْجَنَّةِ، وَأَمَّا الظَّاهِرَانِ النِّيلُ وَالْفُرَاتُ، ثُمَّ فُرِضَتْ عَلَىَّ خَمْسُونَ صَلاَةً، فَأَقْبَلْتُ حَتَّى جِئْتُ مُوسَى، فَقَالَ مَا صَنَعْتَ قُلْتُ فُرِضَتْ عَلَىَّ خَمْسُونَ صَلاَةً‏.‏ قَالَ أَنَا أَعْلَمُ بِالنَّاسِ مِنْكَ، عَالَجْتُ بَنِي إِسْرَائِيلَ أَشَدَّ الْمُعَالَجَةِ، وَإِنَّ أُمَّتَكَ لاَ تُطِيقُ، فَارْجِعْ إِلَى رَبِّكَ فَسَلْهُ‏.‏ فَرَجَعْتُ فَسَأَلْتُهُ، فَجَعَلَهَا أَرْبَعِينَ، ثُمَّ مِثْلَهُ ثُمَّ ثَلاَثِينَ، ثُمَّ مِثْلَهُ فَجَعَلَ عِشْرِينَ، ثُمَّ مِثْلَهُ فَجَعَلَ عَشْرًا، فَأَتَيْتُ مُوسَى فَقَالَ مِثْلَهُ، فَجَعَلَهَا خَمْسًا، فَأَتَيْتُ مُوسَى فَقَالَ مَا صَنَعْتَ قُلْتُ جَعَلَهَا خَمْسًا، فَقَالَ مِثْلَهُ، قُلْتُ سَلَّمْتُ بِخَيْرٍ، فَنُودِيَ إِنِّي قَدْ أَمْضَيْتُ فَرِيضَتِي وَخَفَّفْتُ عَنْ عِبَادِي، وَأَجْزِي الْحَسَنَةَ عَشْرًا ‏"‏‏.‏ وَقَالَ هَمَّامٌ عَنْ قَتَادَةَ عَنِ الْحَسَنِ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ فِي الْبَيْتِ الْمَعْمُورِ ‏"‏‏.‏\hadithno{3207}\hadithtrans{Narrated Malik bin Sasaa:The Prophet (ﷺ) said, "While I was at the House in a state midway between sleep and wakefulness, (an angel recognized me) as the man lying between two men. A golden tray full of wisdom and belief was brought to me and my body was cut open from the throat to the lower part of the `Abdomen and then my `Abdomen was washed with Zamzam water and (my heart was) filled with wisdom and belief. Al- Buraq, a white animal, smaller than a mule and bigger than a donkey was brought to me and I set out with Gabriel. When I reached the nearest heaven. Gabriel said to the heaven's gate-keeper, 'Open the gate.' The gatekeeper asked, 'Who is it?' He said, 'Gabriel.' The gate-keeper asked,' Who is accompanying you?' Gabriel said, 'Muhammad.' The gate-keeper said, 'Has he been called?' Gabriel said, 'Yes.' Then it was said, 'He is welcomed. What a wonderful visit his is!' Then I met Adam and greeted him and he said, 'You are welcomed O son and a Prophet.' Then we ascended to the second heaven. It was asked, 'Who is it?' Gabriel said, 'Gabriel.' It was said, 'Who is with you?' He said, 'Muhammad.' It was asked, 'Has he been sent for?' He said, 'Yes.' It was said, 'He is welcomed. What a wonderful visit his is!" Then I met Jesus and Yahya (John) who said, 'You are welcomed, O brother and a Prophet.' Then we ascended to the third heaven. It was asked, 'Who is it?' Gabriel said, 'Gabriel.' It was asked, 'Who is with you? Gabriel said, 'Muhammad.' It was asked, 'Has he been sent for?' 'Yes,' said Gabriel. It was said, 'He is welcomed. What a wonderful visit his is!' (The Prophet (ﷺ) added:) There I met Joseph and greeted him, and he replied, 'You are welcomed, O brother and a Prophet!' Then we ascended to the 4th heaven and again the same questions and answers were exchanged as in the previous heavens. There I met Idris and greeted him. He said, 'You are welcomed O brother and Prophet.' Then we ascended to the 5th heaven and again the same questions and answers were exchanged as in previous heavens. there I met and greeted Aaron who said, 'You are welcomed O brother and a Prophet". Then we ascended to the 6th heaven and again the same questions and answers were exchanged as in the previous heavens. There I met and greeted Moses who said, 'You are welcomed O brother and. a Prophet.' When I proceeded on, he started weeping and on being asked why he was weeping, he said, 'O Lord! Followers of this youth who was sent after me will enter Paradise in greater number than my followers.' Then we ascended to the seventh heaven and again the same questions and answers were exchanged as in the previous heavens. There I met and greeted Abraham who said, 'You are welcomed O son and a Prophet.' Then I was shown Al-Bait-al-Ma'mur (i.e. Allah's House). I asked Gabriel about it and he said, This is Al Bait-ul-Ma'mur where 70,000 angels perform prayers daily and when they leave they never return to it (but always a fresh batch comes into it daily).' Then I was shown Sidrat-ul-Muntaha (i.e. a tree in the seventh heaven) and I saw its Nabk fruits which resembled the clay jugs of Hajr (i.e. a town in Arabia), and its leaves were like the ears of elephants, and four rivers originated at its root, two of them were apparent and two were hidden. I asked Gabriel about those rivers and he said, 'The two hidden rivers are in Paradise, and the apparent ones are the Nile and the Euphrates.' Then fifty prayers were enjoined on me. I descended till I met Moses who asked me, 'What have you done?' I said, 'Fifty prayers have been enjoined on me.' He said, 'I know the people better than you, because I had the hardest experience to bring Bani Israel to obedience. Your followers cannot put up with such obligation. So, return to your Lord and request Him (to reduce the number of prayers.' I returned and requested Allah (for reduction) and He made it forty. I returned and (met Moses) and had a similar discussion, and then returned again to Allah for reduction and He made it thirty, then twenty, then ten, and then I came to Moses who repeated the same advice. Ultimately Allah reduced it to five. When I came to Moses again, he said, 'What have you done?' I said, 'Allah has made it five only.' He repeated the same advice but I said that I surrendered (to Allah's Final Order)'" Allah's Messenger (ﷺ) was addressed by Allah, "I have decreed My Obligation and have reduced the burden on My slaves, and I shall reward a single good deed as if it were ten good deeds}}
\hadithdefcmd{bukhari}{3208}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ عَبْدُ اللَّهِ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ الصَّادِقُ الْمَصْدُوقُ قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ يُجْمَعُ خَلْقُهُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا، ثُمَّ يَكُونُ عَلَقَةً مِثْلَ ذَلِكَ، ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ، ثُمَّ يَبْعَثُ اللَّهُ مَلَكًا، فَيُؤْمَرُ بِأَرْبَعِ كَلِمَاتٍ، وَيُقَالُ لَهُ اكْتُبْ عَمَلَهُ وَرِزْقَهُ وَأَجَلَهُ وَشَقِيٌّ أَوْ سَعِيدٌ‏.‏ ثُمَّ يُنْفَخُ فِيهِ الرُّوحُ، فَإِنَّ الرَّجُلَ مِنْكُمْ لَيَعْمَلُ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَ الْجَنَّةِ إِلاَّ ذِرَاعٌ، فَيَسْبِقُ عَلَيْهِ كِتَابُهُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ، وَيَعْمَلُ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَ النَّارِ إِلاَّ ذِرَاعٌ، فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{3208}\hadithtrans{Narrated `Abdullah bin Mas'ud:Allah's Messenger (ﷺ), the true and truly inspired said, "(The matter of the Creation of) a human being is put together in the womb of the mother in forty days, and then he becomes a clot of thick blood for a similar period, and then a piece of flesh for a similar period. Then Allah sends an angel who is ordered to write four things. He is ordered to write down his (i.e. the new creature's) deeds, his livelihood, his (date of) death, and whether he will be blessed or wretched (in religion). Then the soul is breathed into him. So, a man amongst you may do (good deeds till there is only a cubit between him and Paradise and then what has been written for him decides his behavior and he starts doing (evil) deeds characteristic of the people of the (Hell) Fire. And similarly a man amongst you may do (evil) deeds till there is only a cubit between him and the (Hell) Fire, and then what has been written for him decides his behavior, and he starts doing deeds characteristic of the people of Paradise}}
\hadithdefcmd{bukhari}{3209}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا مَخْلَدٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَتَابَعَهُ أَبُو عَاصِمٍ عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَحَبَّ اللَّهُ الْعَبْدَ نَادَى جِبْرِيلَ إِنَّ اللَّهَ يُحِبُّ فُلاَنًا فَأَحْبِبْهُ‏.‏ فَيُحِبُّهُ جِبْرِيلُ، فَيُنَادِي جِبْرِيلُ فِي أَهْلِ السَّمَاءِ إِنَّ اللَّهَ يُحِبُّ فُلاَنًا فَأَحِبُّوهُ‏.‏ فَيُحِبُّهُ أَهْلُ السَّمَاءِ، ثُمَّ يُوضَعُ لَهُ الْقَبُولُ فِي الأَرْضِ ‏"‏‏.‏\hadithno{3209}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If Allah loves a person, He calls Gabriel saying, 'Allah loves so and-so; O Gabriel! Love him.' Gabriel would love him and make an announcement amongst the inhabitants of the Heaven. 'Allah loves so-and-so, therefore you should love him also,' and so all the inhabitants of the Heaven would love him, and then he is granted the pleasure of the people on the earth}}
\hadithdefcmd{bukhari}{3210}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا اللَّيْثُ، حَدَّثَنَا ابْنُ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْمَلاَئِكَةَ تَنْزِلُ فِي الْعَنَانِ ـ وَهْوَ السَّحَابُ ـ فَتَذْكُرُ الأَمْرَ قُضِيَ فِي السَّمَاءِ، فَتَسْتَرِقُ الشَّيَاطِينُ السَّمْعَ، فَتَسْمَعُهُ فَتُوحِيهِ إِلَى الْكُهَّانِ، فَيَكْذِبُونَ مَعَهَا مِائَةَ كَذْبَةٍ مِنْ عِنْدِ أَنْفُسِهِمْ ‏"‏‏.‏\hadithno{3210}\hadithtrans{Narrated `Aisha:I heard Allah's Messenger (ﷺ) saying, "The angels descend to the clouds and mention this or that matter decreed in the Heaven. The devils listen stealthily to such a matter, come down to inspire the soothsayers with it, and the latter would add to it one-hundred lies of their own}}
\hadithdefcmd{bukhari}{3211}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَالأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ كَانَ عَلَى كُلِّ باب مِنْ أَبْوَابِ الْمَسْجِدِ الْمَلاَئِكَةُ، يَكْتُبُونَ الأَوَّلَ فَالأَوَّلَ، فَإِذَا جَلَسَ الإِمَامُ طَوَوُا الصُّحُفَ وَجَاءُوا يَسْتَمِعُونَ الذِّكْرَ ‏"‏‏.‏\hadithno{3211}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "On every Friday the angels take their stand at every gate of the mosque to write the names of the people chronologically (i.e. according to the time of their arrival for the Friday prayer) and when the Imam sits (on the pulpit) they fold up their scrolls and get ready to listen to the sermon}}
\hadithdefcmd{bukhari}{3212}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ مَرَّ عُمَرُ فِي الْمَسْجِدِ وَحَسَّانُ يُنْشِدُ، فَقَالَ كُنْتُ أُنْشِدُ فِيهِ، وَفِيهِ مَنْ هُوَ خَيْرٌ مِنْكَ، ثُمَّ الْتَفَتَ إِلَى أَبِي هُرَيْرَةَ، فَقَالَ أَنْشُدُكَ بِاللَّهِ، أَسَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَجِبْ عَنِّي، اللَّهُمَّ أَيِّدْهُ بِرُوحِ الْقُدُسِ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏\hadithno{3212}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:`Umar came to the Mosque while Hassan was reciting a poem. (`Umar disapproved of that). On that Hassan said, "I used to recite poetry in this very Mosque in the presence of one (i.e. the Prophet (ﷺ) ) who was better than you." Then he turned towards Abu Huraira and said (to him), "I ask you by Allah, did you hear Allah's Messenger (ﷺ) saying (to me), "Retort on my behalf. O Allah! Support him (i.e. Hassan) with the Holy Spirit?" Abu Huraira said, "Yes}}
\hadithdefcmd{bukhari}{3213}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لِحَسَّانَ ‏ "‏ اهْجُهُمْ ـ أَوْ هَاجِهِمْ ـ وَجِبْرِيلُ مَعَكَ ‏"‏‏.‏\hadithno{3213}\hadithtrans{Narrated Al Bara:The Prophet (ﷺ) said to Hassan, "Lampoon them (i.e. the pagans) and Gabriel is with you}}
\hadithdefcmd{bukhari}{3214}{وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ حُمَيْدَ بْنَ هِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَأَنِّي أَنْظُرُ إِلَى غُبَارٍ سَاطِعٍ فِي سِكَّةِ بَنِي غَنْمٍ‏.‏ زَادَ مُوسَى مَوْكِبَ جِبْرِيلَ‏.‏\hadithno{3214}\hadithtrans{Narrated Jarir:as below. Narrated Humaid bin Hilal: Anas bin Malik said, "As if I see a cloud of dust swirling up in the lane of Bani Ghanim." Musa added, "That was caused by the procession of Gabriel}}
\hadithdefcmd{bukhari}{3215}{حَدَّثَنَا فَرْوَةُ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ الْحَارِثَ بْنَ هِشَامٍ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم كَيْفَ يَأْتِيكَ الْوَحْىُ قَالَ ‏ "‏ كُلُّ ذَاكَ يَأْتِي الْمَلَكُ أَحْيَانًا فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ، فَيَفْصِمُ عَنِّي وَقَدْ وَعَيْتُ مَا قَالَ، وَهْوَ أَشَدُّهُ عَلَىَّ، وَيَتَمَثَّلُ لِي الْمَلَكُ أَحْيَانًا رَجُلاً، فَيُكَلِّمُنِي فَأَعِي مَا يَقُولُ ‏"‏‏.‏\hadithno{3215}\hadithtrans{Narrated Aisha:Al Harith bin Hisham asked the Prophet, "How does the divine inspiration come to you?" He replied, "In all these ways: The Angel sometimes comes to me with a voice which resembles the sound of a ringing bell, and when this state abandons me, I remember what the Angel has said, and this type of Divine Inspiration is the hardest on me; and sometimes the Angel comes to me in the shape of a man and talks to me, and I understand and remember what he says}}
\hadithdefcmd{bukhari}{3216}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ دَعَتْهُ خَزَنَةُ الْجَنَّةِ أَىْ فُلُ هَلُمَّ ‏"‏‏.‏ فَقَالَ أَبُو بَكْرٍ ذَاكَ الَّذِي لاَ تَوَى عَلَيْهِ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏‏.‏\hadithno{3216}\hadithtrans{Narrated Abu Huraira:I heard the Prophet (ﷺ) saying, "Who ever spends a couple (of objects) in Allah's cause, will be called by the Gatekeepers of Paradise who will say, "O so-and-so, come on!" Abu Bakr said, "Such a person will never perish or be miserable' The Prophet (ﷺ) said, "I hope you will be among such person}}
\hadithdefcmd{bukhari}{3217}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ يَا عَائِشَةُ، هَذَا جِبْرِيلُ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏‏.‏ فَقَالَتْ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ‏.‏ تَرَى مَا لاَ أَرَى‏.‏ تُرِيدُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{3217}\hadithtrans{Narrated Abu Salama:`Aisha said that the Prophet (ﷺ) said to her "O `Aisha' This is Gabriel and he sends his (greetings) salutations to you." `Aisha said, "Salutations (Greetings) to him, and Allah's Mercy and Blessings be on him," and addressing the Prophet (ﷺ) she said, "You see what I don't see}}
\hadithdefcmd{bukhari}{3218}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ، ح قَالَ حَدَّثَنِي يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عُمَرَ بْنِ ذَرٍّ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِجِبْرِيلَ ‏"‏ أَلاَ تَزُورُنَا أَكْثَرَ مِمَّا تَزُورُنَا ‏"‏ قَالَ فَنَزَلَتْ ‏\{‏وَمَا نَتَنَزَّلُ إِلاَّ بِأَمْرِ رَبِّكَ لَهُ مَا بَيْنَ أَيْدِينَا وَمَا خَلْفَنَا‏\}‏ الآيَةَ‏.‏\hadithno{3218}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) asked Gabriel, "Why don't you visit us more often than you do?" Then the following Holy Verse was revealed (in this respect):-- "And we (angels) descend not but by the order of your Lord. To Him belongs what is before us and what is behind us, and what is between those two and your Lord was never forgetful}}
\hadithdefcmd{bukhari}{3219}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَقْرَأَنِي جِبْرِيلُ عَلَى حَرْفٍ، فَلَمْ أَزَلْ أَسْتَزِيدُهُ حَتَّى انْتَهَى إِلَى سَبْعَةِ أَحْرُفٍ ‏"‏‏.‏\hadithno{3219}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "Gabriel read the Qur'an to me in one way (i.e. dialect) and I continued asking him to read it in different ways till he read it in seven different ways}}
\hadithdefcmd{bukhari}{3220}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَجْوَدَ النَّاسِ، وَكَانَ أَجْوَدَ مَا يَكُونُ فِي رَمَضَانَ حِينَ يَلْقَاهُ جِبْرِيلُ، وَكَانَ جِبْرِيلُ يَلْقَاهُ فِي كُلِّ لَيْلَةٍ مِنْ رَمَضَانَ، فَيُدَارِسُهُ الْقُرْآنَ، فَلَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ يَلْقَاهُ جِبْرِيلُ أَجْوَدُ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ‏.‏ وَعَنْ عَبْدِ اللَّهِ حَدَّثَنَا مَعْمَرٌ بِهَذَا الإِسْنَادِ نَحْوَهُ‏.‏ وَرَوَى أَبُو هُرَيْرَةَ وَفَاطِمَةُ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ جِبْرِيلَ كَانَ يُعَارِضُهُ الْقُرْآنَ‏.‏\hadithno{3220}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) was the most generous of all the people, and he used to be more generous in the month of Ramadan when Gabriel used to meet him. Gabriel used to meet him every night in Ramadan to study the Holy Qur'an carefully together. Allah's Messenger (ﷺ) used to become more generous than the fast wind when he met Gabriel}}
\hadithdefcmd{bukhari}{3221}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الْعَصْرَ شَيْئًا فَقَالَ لَهُ عُرْوَةُ أَمَا إِنَّ جِبْرِيلَ قَدْ نَزَلَ فَصَلَّى أَمَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ عُمَرُ اعْلَمْ مَا تَقُولُ يَا عُرْوَةُ‏.‏ قَالَ سَمِعْتُ بَشِيرَ بْنَ أَبِي مَسْعُودٍ يَقُولُ سَمِعْتُ أَبَا مَسْعُودٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَزَلَ جِبْرِيلُ فَأَمَّنِي، فَصَلَّيْتُ مَعَهُ، ثُمَّ صَلَّيْتُ مَعَهُ، ثُمَّ صَلَّيْتُ مَعَهُ، ثُمَّ صَلَّيْتُ مَعَهُ، ثُمَّ صَلَّيْتُ مَعَهُ ‏"‏‏.‏ يَحْسُبُ بِأَصَابِعِهِ خَمْسَ صَلَوَاتٍ‏.‏\hadithno{3221}\hadithtrans{Narrated Ibn Shihab:Once `Umar bin `Abdul `Aziz delayed the `Asr prayer a little. `Urwa said to him, "Gabriel descended and led the prayer in front of the Prophet (ﷺ) " On that `Umar said, "O `Urwa! Be sure of what you say." "Urwa said, "I heard Bashir bin Abi Masud narrating from Ibn Masud who heard Allah's Messenger (ﷺ) saying, 'Gabriel descended and led me in prayer; and then prayed with him again, and then prayed with him again, and then prayed with him again, and then prayed with him again, counting with his fingers five prayers}}
\hadithdefcmd{bukhari}{3222}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ قَالَ لِي جِبْرِيلُ مَنْ مَاتَ مِنْ أُمَّتِكَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ، أَوْ لَمْ يَدْخُلِ النَّارَ، قَالَ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ وَإِنْ ‏"‏‏.‏\hadithno{3222}\hadithtrans{Narrated Abu Dhar:The Prophet (ﷺ) said, "Gabriel said to me, 'Whoever amongst your followers dies without having worshipped others besides Allah, will enter Paradise (or will not enter the (Hell) Fire)." The Prophet (ﷺ) asked. "Even if he has committed illegal sexual intercourse or theft?" He replied, "Even then}}
\hadithdefcmd{bukhari}{3223}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْمَلاَئِكَةُ يَتَعَاقَبُونَ، مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ، وَيَجْتَمِعُونَ فِي صَلاَةِ الْفَجْرِ وَالْعَصْرِ، ثُمَّ يَعْرُجُ إِلَيْهِ الَّذِينَ بَاتُوا فِيكُمْ، فَيَسْأَلُهُمْ وَهْوَ أَعْلَمُ، فَيَقُولُ كَيْفَ تَرَكْتُمْ ‏\{‏عِبَادِي‏\}‏ فَيَقُولُونَ تَرَكْنَاهُمْ يُصَلُّونَ، وَأَتَيْنَاهُمْ يُصَلُّونَ ‏"‏‏.‏\hadithno{3223}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Angels keep on descending from and ascending to the Heaven in turn, some at night and some by daytime, and all of them assemble together at the time of the Fajr and `Asr prayers. Then those who have stayed with you over-night, ascend unto Allah Who asks them, and He knows the answer better than they, "How have you left My slaves?" They reply, "We have left them praying as we found them praying." If anyone of you says "Amin" (during the Prayer at the end of the recitation of Surat-al-Fatiha), and the angels in Heaven say the same, and the two sayings coincide, all his past sins will be forgiven}}
\hadithdefcmd{bukhari}{3224}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، أَنَّ نَافِعًا، حَدَّثَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ حَدَّثَهُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ حَشَوْتُ لِلنَّبِيِّ صلى الله عليه وسلم وِسَادَةً فِيهَا تَمَاثِيلُ كَأَنَّهَا نُمْرُقَةٌ، فَجَاءَ فَقَامَ بَيْنَ الْبَابَيْنِ وَجَعَلَ يَتَغَيَّرُ وَجْهُهُ، فَقُلْتُ مَا لَنَا يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ مَا بَالُ هَذِهِ الْوِسَادَةِ ‏"‏‏.‏ قَالَتْ وِسَادَةٌ جَعَلْتُهَا لَكَ لِتَضْطَجِعَ عَلَيْهَا‏.‏ قَالَ ‏"‏ أَمَا عَلِمْتِ أَنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ صُورَةٌ، وَأَنَّ مَنْ صَنَعَ الصُّورَةَ يُعَذَّبُ يَوْمَ الْقِيَامَةِ يَقُولُ أَحْيُوا مَا خَلَقْتُمْ ‏"‏‏.‏\hadithno{3224}\hadithtrans{Narrated `Aisha:I stuffed for the Prophet (ﷺ) a pillow decorated with pictures (of animals) which looked like a Namruqa (i.e. a small cushion). He came and stood between the two doors and his face began to change. I said, "O Allah's Messenger (ﷺ)! What did we do wrong?" He said, "What is this pillow?" I said, "I have prepared this pillow for you, so that you may recline on it." He said, "Don't you know that angels do not enter a house wherein there are pictures; and whoever makes a picture will be punished on the Day of Resurrection and will be asked to give life to (what he has created)?}}
\hadithdefcmd{bukhari}{3225}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ سَمِعْتُ أَبَا طَلْحَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةُ تَمَاثِيلَ ‏"‏‏.‏\hadithno{3225}\hadithtrans{Narrated Abu Talha:I heard Allah's Messenger (ﷺ) saying; "Angels (of Mercy) do not enter a house wherein there is a dog or a picture of a living creature (a human being or an animal)}}
\hadithdefcmd{bukhari}{3226}{حَدَّثَنَا أَحْمَدُ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ بُكَيْرَ بْنَ الأَشَجِّ، حَدَّثَهُ أَنَّ بُسْرَ بْنَ سَعِيدٍ حَدَّثَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ ـ رضى الله عنه ـ حَدَّثَهُ وَمَعَ، بُسْرِ بْنِ سَعِيدٍ عُبَيْدُ اللَّهِ الْخَوْلاَنِيُّ الَّذِي كَانَ فِي حَجْرِ مَيْمُونَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حَدَّثَهُمَا زَيْدُ بْنُ خَالِدٍ أَنَّ أَبَا طَلْحَةَ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ صُورَةٌ ‏"‏‏.‏ قَالَ بُسْرٌ فَمَرِضَ زَيْدُ بْنُ خَالِدٍ، فَعُدْنَاهُ فَإِذَا نَحْنُ فِي بَيْتِهِ بِسِتْرٍ فِيهِ تَصَاوِيرُ، فَقُلْتُ لِعُبَيْدِ اللَّهِ الْخَوْلاَنِيِّ أَلَمْ يُحَدِّثْنَا فِي التَّصَاوِيرِ فَقَالَ إِنَّهُ قَالَ ‏"‏ إِلاَّ رَقْمٌ فِي ثَوْبٍ ‏"‏‏.‏ أَلاَ سَمِعْتَهُ قُلْتُ لاَ‏.‏ قَالَ بَلَى قَدْ ذَكَرَهُ‏.‏\hadithno{3226}\hadithtrans{Narrated Busr bin Sa`id:That Zaid bin Khalid Al-Juhani narrated to him something in the presence of Sa`id bin 'Ubaidullah Al- Khaulani who was brought up in the house of Maimuna the wife of the Prophet. Zaid narrated to them that Abu Talha said that the Prophet (ﷺ) said, "The Angels (of Mercy) do not enter a house wherein there is a picture." Busr said, "Later on Zaid bin Khalid fell ill and we called on him. To our surprise we saw a curtain decorated with pictures in his house. I said to Ubaidullah Al-Khaulani, "Didn't he (i.e. Zaid) tell us about the (prohibition of) pictures?" He said, "But he excepted the embroidery on garments. Didn't you hear him?" I said, "No." He said, "Yes, he did}}
\hadithdefcmd{bukhari}{3227}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ وَعَدَ النَّبِيَّ صلى الله عليه وسلم جِبْرِيلُ فَقَالَ إِنَّا لاَ نَدْخُلُ بَيْتًا فِيهِ صُورَةٌ وَلاَ كَلْبٌ‏.‏\hadithno{3227}\hadithtrans{Narrated Salim's father:Once Gabriel promised the Prophet (that he would visit him, but Gabriel did not come) and later on he said, "We, angels, do not enter a house which contains a picture or a dog}}
\hadithdefcmd{bukhari}{3228}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ، فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ، غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏\hadithno{3228}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Imam, during the prayer, says, "Allah hears him who praises Him', say: 'O Allah! Our Lord! All the praises are for You/, for if the saying of anyone of you coincides with the saying of the angels, his past sins will be forgiven}}
\hadithdefcmd{bukhari}{3229}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، حَدَّثَنَا أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ فِي صَلاَةٍ مَا دَامَتِ الصَّلاَةُ تَحْبِسُهُ، وَالْمَلاَئِكَةُ تَقُولُ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ‏.‏ مَا لَمْ يَقُمْ مِنْ صَلاَتِهِ أَوْ يُحْدِثْ ‏"‏‏.‏\hadithno{3229}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "As long as any-one of you is waiting for the prayer, he is considered to be praying actually, and the angels say, 'O Allah! Be merciful to him and forgive him', (and go on saying so) unless he leaves his place of praying or passes wind (i.e. breaks his ablution)}}
\hadithdefcmd{bukhari}{3230}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏\{‏وَنَادَوْا يَا مَالِكُ‏\}‏‏.‏ قَالَ سُفْيَانُ فِي قِرَاءَةِ عَبْدِ اللَّهِ وَنَادَوْا يَا مَالِ‏.‏\hadithno{3230}\hadithtrans{Narrated Yali:I heard the Prophet (ﷺ) reciting the following Verse on the pulpit: "They will call: O Malik...' and Sufyan said that `Abdullah recited it: 'They will call: O Mali}}
\hadithdefcmd{bukhari}{3231}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَدَّثَتْهُ أَنَّهَا قَالَتْ لِلنَّبِيِّ صلى الله عليه وسلم هَلْ أَتَى عَلَيْكَ يَوْمٌ كَانَ أَشَدَّ مِنْ يَوْمِ أُحُدٍ قَالَ ‏ "‏ لَقَدْ لَقِيتُ مِنْ قَوْمِكِ مَا لَقِيتُ، وَكَانَ أَشَدُّ مَا لَقِيتُ مِنْهُمْ يَوْمَ الْعَقَبَةِ، إِذْ عَرَضْتُ نَفْسِي عَلَى ابْنِ عَبْدِ يَالِيلَ بْنِ عَبْدِ كُلاَلٍ، فَلَمْ يُجِبْنِي إِلَى مَا أَرَدْتُ، فَانْطَلَقْتُ وَأَنَا مَهْمُومٌ عَلَى وَجْهِي، فَلَمْ أَسْتَفِقْ إِلاَّ وَأَنَا بِقَرْنِ الثَّعَالِبِ، فَرَفَعْتُ رَأْسِي، فَإِذَا أَنَا بِسَحَابَةٍ قَدْ أَظَلَّتْنِي، فَنَظَرْتُ فَإِذَا فِيهَا جِبْرِيلُ فَنَادَانِي فَقَالَ إِنَّ اللَّهَ قَدْ سَمِعَ قَوْلَ قَوْمِكَ لَكَ وَمَا رَدُّوا عَلَيْكَ، وَقَدْ بَعَثَ إِلَيْكَ مَلَكَ الْجِبَالِ لِتَأْمُرَهُ بِمَا شِئْتَ فِيهِمْ، فَنَادَانِي مَلَكُ الْجِبَالِ، فَسَلَّمَ عَلَىَّ ثُمَّ قَالَ يَا مُحَمَّدُ، فَقَالَ ذَلِكَ فِيمَا شِئْتَ، إِنْ شِئْتَ أَنْ أُطْبِقَ عَلَيْهِمِ الأَخْشَبَيْنِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم بَلْ أَرْجُو أَنْ يُخْرِجَ اللَّهُ مِنْ أَصْلاَبِهِمْ مَنْ يَعْبُدُ اللَّهَ وَحْدَهُ لاَ يُشْرِكُ بِهِ شَيْئًا ‏"‏‏.‏\hadithno{3231}\hadithtrans{Narrated `Aisha:That she asked the Prophet (ﷺ) , 'Have you encountered a day harder than the day of the battle) of Uhud?" The Prophet (ﷺ) replied, "Your tribes have troubled me a lot, and the worse trouble was the trouble on the day of 'Aqaba when I presented myself to Ibn `Abd-Yalail bin `Abd-Kulal and he did not respond to my demand. So I departed, overwhelmed with excessive sorrow, and proceeded on, and could not relax till I found myself at Qarnath-Tha-alib where I lifted my head towards the sky to see a cloud shading me unexpectedly. I looked up and saw Gabriel in it. He called me saying, 'Allah has heard your people's saying to you, and what they have replied back to you, Allah has sent the Angel of the Mountains to you so that you may order him to do whatever you wish to these people.' The Angel of the Mountains called and greeted me, and then said, "O Muhammad! Order what you wish. If you like, I will let Al-Akh-Shabain (i.e. two mountains) fall on them." The Prophet (ﷺ) said, "No but I hope that Allah will let them beget children who will worship Allah Alone, and will worship None besides Him}}
\hadithdefcmd{bukhari}{3232}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، قَالَ سَأَلْتُ زِرَّ بْنَ حُبَيْشٍ عَنْ قَوْلِ اللَّهِ، تَعَالَى ‏\{‏فَكَانَ قَابَ قَوْسَيْنِ أَوْ أَدْنَى * فَأَوْحَى إِلَى عَبْدِهِ مَا أَوْحَى‏\}‏‏.‏ قَالَ حَدَّثَنَا ابْنُ مَسْعُودٍ أَنَّهُ رَأَى جِبْرِيلَ لَهُ سِتُّمِائَةِ جَنَاحٍ‏.‏\hadithno{3232}\hadithtrans{Narrated Abu 'Is-haq-Ash-Shaibani:I asked Zir bin Hubaish regarding the Statement of Allah: "And was at a distance Of but two bowlengths Or (even) nearer; So did (Allah) convey The Inspiration to His slave (Gabriel) and then he (Gabriel) Conveyed (that to Muhammad). (53.9-10) On that, Zir said, "Ibn Mas`ud informed us that the Prophet (ﷺ) had seen Gabriel having 600 wings}}
\hadithdefcmd{bukhari}{3233}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه – ‏\{‏لَقَدْ رَأَى مِنْ آيَاتِ رَبِّهِ الْكُبْرَى‏\}‏ قَالَ رَأَى رَفْرَفًا أَخْضَرَ سَدَّ أُفُقَ السَّمَاءِ‏.‏\hadithno{3233}\hadithtrans{Narrated `Abdullah:Regarding the Verse: "Indeed he (Muhammad) did see. Of the Signs of his Lord, The Greatest!" (53.18) That the Prophet (ﷺ) had seen a green carpet spread all over the horizon of the sky}}
\hadithdefcmd{bukhari}{3234}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنِ ابْنِ عَوْنٍ، أَنْبَأَنَا الْقَاسِمُ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَنْ زَعَمَ أَنَّ مُحَمَّدًا رَأَى رَبَّهُ فَقَدْ أَعْظَمَ، وَلَكِنْ قَدْ رَأَى جِبْرِيلَ فِي صُورَتِهِ، وَخَلْقُهُ سَادٌّ مَا بَيْنَ الأُفُقِ‏.‏\hadithno{3234}\hadithtrans{Narrated Aisha:Whoever claimed that (the Prophet) Muhammad saw his Lord, is committing a great fault, for he only saw Gabriel in his genuine shape in which he was created covering the whole horizon}}
\hadithdefcmd{bukhari}{3235}{حَدَّثَنِي مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ أَبِي زَائِدَةَ، عَنِ ابْنِ الأَشْوَعِ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ قُلْتُ لِعَائِشَةَ ـ رضى الله عنها ـ فَأَيْنَ قَوْلُهُ ‏\{‏ثُمَّ دَنَا فَتَدَلَّى * فَكَانَ قَابَ قَوْسَيْنِ أَوْ أَدْنَى‏\}‏ قَالَتْ ذَاكَ جِبْرِيلُ كَانَ يَأْتِيهِ فِي صُورَةِ الرَّجُلِ، وَإِنَّهُ أَتَاهُ هَذِهِ الْمَرَّةَ فِي صُورَتِهِ الَّتِي هِيَ صُورَتُهُ، فَسَدَّ الأُفُقَ‏.‏\hadithno{3235}\hadithtrans{Narrated Masruq:I asked Aisha "What about His Statement:-- "Then he (Gabriel) approached And came closer, And was at a distance Of but two bow-lengths Or (even) nearer?" (53.8-9) She replied, "It was Gabriel who used to come to the Prophet (ﷺ) in the figure of a man, but on that occasion, he came in his actual and real figure and (he was so huge) that he covered the whole horizon}}
\hadithdefcmd{bukhari}{3236}{حَدَّثَنَا مُوسَى، حَدَّثَنَا جَرِيرٌ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ سَمُرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ اللَّيْلَةَ رَجُلَيْنِ أَتَيَانِي قَالاَ الَّذِي يُوقِدُ النَّارَ مَالِكٌ خَازِنُ النَّارِ، وَأَنَا جِبْرِيلُ، وَهَذَا مِيكَائِيلُ ‏"‏‏.‏\hadithno{3236}\hadithtrans{Narrated Samura:The Prophet (ﷺ) said, "Last night I saw (in a dream) two men coming to me. One of them said, "The person who kindles the fire is Malik, the gate-keeper of the (Hell) Fire, and I am Gabriel, and this is Michael}}
\hadithdefcmd{bukhari}{3237}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا الرَّجُلُ امْرَأَتَهُ إِلَى فِرَاشِهِ فَأَبَتْ، فَبَاتَ غَضْبَانَ عَلَيْهَا، لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تُصْبِحَ ‏"‏‏.‏ تَابَعَهُ شُعْبَةُ وَأَبُو حَمْزَةَ وَابْنُ دَاوُدَ وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ‏.‏\hadithno{3237}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If a husband calls his wife to his bed (i.e. to have sexual relation) and she refuses and causes him to sleep in anger, the angels will curse her till morning}}
\hadithdefcmd{bukhari}{3238}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، قَالَ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ ثُمَّ فَتَرَ عَنِّي الْوَحْىُ فَتْرَةً، فَبَيْنَا أَنَا أَمْشِي سَمِعْتُ صَوْتًا مِنَ السَّمَاءِ، فَرَفَعْتُ بَصَرِي قِبَلَ السَّمَاءِ فَإِذَا الْمَلَكُ الَّذِي جَاءَنِي بِحِرَاءٍ قَاعِدٌ عَلَى كُرْسِيٍّ بَيْنَ السَّمَاءِ وَالأَرْضِ، فَجُئِثْتُ مِنْهُ حَتَّى هَوَيْتُ إِلَى الأَرْضِ، فَجِئْتُ أَهْلِي فَقُلْتُ زَمِّلُونِي زَمِّلُونِي‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الْمُدَّثِّرُ‏\}‏ إِلَى ‏\{‏فَاهْجُرْ‏\}‏ ‏"‏‏.‏ قَالَ أَبُو سَلَمَةَ وَالرِّجْزُ الأَوْثَانُ‏.‏\hadithno{3238}\hadithtrans{Narrated Jabir bin `Abdullah:that he heard the Prophet (ﷺ) saying, "The Divine Inspiration was delayed for a short period but suddenly, as I was walking. I heard a voice in the sky, and when I looked up towards the sky, to my surprise, I saw the angel who had come to me in the Hira Cave, and he was sitting on a chair in between the sky and the earth. I was so frightened by him that I fell on the ground and came to my family and said (to them), 'Cover me! (with a blanket), cover me!' Then Allah sent the Revelation: "O, You wrapped up (In a blanket)! (Arise and warn! And your Lord magnify And keep pure your garments, And desert the idols)}}
\hadithdefcmd{bukhari}{3239}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ،‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، حَدَّثَنَا ابْنُ عَمِّ، نَبِيِّكُمْ يَعْنِي ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ رَأَيْتُ لَيْلَةَ أُسْرِيَ بِي مُوسَى رَجُلاً آدَمَ طُوَالاً جَعْدًا، كَأَنَّهُ مِنْ رِجَالِ شَنُوءَةَ، وَرَأَيْتُ عِيسَى رَجُلاً مَرْبُوعًا مَرْبُوعَ الْخَلْقِ إِلَى الْحُمْرَةِ وَالْبَيَاضِ، سَبْطَ الرَّأْسِ، وَرَأَيْتُ مَالِكًا خَازِنَ النَّارِ ‏"‏‏.‏ وَالدَّجَّالَ فِي آيَاتٍ أَرَاهُنَّ اللَّهُ إِيَّاهُ، فَلاَ تَكُنْ فِي مِرْيَةٍ مِنْ لِقَائِهِ‏.‏ قَالَ أَنَسٌ وَأَبُو بَكْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ تَحْرُسُ الْمَلاَئِكَةُ الْمَدِينَةَ مِنَ الدَّجَّالِ ‏"‏‏.‏\hadithno{3239}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "On the night of my Ascent to the Heaven, I saw Moses who was a tall brown curlyhaired man as if he was one of the men of Shan'awa tribe, and I saw Jesus, a man of medium height and moderate complexion inclined to the red and white colors and of lank hair. I also saw Malik, the gate-keeper of the (Hell) Fire and Ad-Dajjal amongst the signs which Allah showed me." (The Prophet then recited the Holy Verse): "So be not you in doubt of meeting him' when you met Moses during the night of Mi'raj over the heavens" (32.23) Narrated Anas and Abu Bakra: "The Prophet (ﷺ) said, "The angels will guard Medina from Ad-Dajjal (who will not be able to enter the city of Medina)}}
\hadithdefcmd{bukhari}{3240}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَاتَ أَحَدُكُمْ فَإِنَّهُ يُعْرَضُ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ، فَإِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ، وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ ‏"‏‏.‏\hadithno{3240}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "When anyone of you dies, he will be shown his destination both in the morning and in the evening, and if he belongs to the people of Paradise, he will be shown his place in Paradise, and if he is from the people of Hell, he will be shown his place in Hell}}
\hadithdefcmd{bukhari}{3241}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا سَلْمُ بْنُ زَرِيرٍ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ، وَاطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏\hadithno{3241}\hadithtrans{Narrated `Imran bin Husain:The Prophet (ﷺ) said, "I looked at Paradise and found poor people forming the majority of its inhabitants; and I looked at Hell and saw that the majority of its inhabitants were women}}
\hadithdefcmd{bukhari}{3242}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي فِي الْجَنَّةِ، فَإِذَا امْرَأَةٌ تَتَوَضَّأُ إِلَى جَانِبِ قَصْرٍ، فَقُلْتُ لِمَنْ هَذَا الْقَصْرُ فَقَالُوا لِعُمَرَ بْنِ الْخَطَّابِ، فَذَكَرْتُ غَيْرَتَهُ، فَوَلَّيْتُ مُدْبِرًا ‏"‏‏.‏ فَبَكَى عُمَرُ وَقَالَ أَعَلَيْكَ أَغَارُ يَا رَسُولَ اللَّهِ‏.‏\hadithno{3242}\hadithtrans{Narrated Abu Huraira:While we were in the company of the Prophet, he said, "While I was asleep, I saw myself in Paradise and there I beheld a woman making ablution beside a palace, I asked, To whom does this palace belong? 'They said, To `Umar bin Al-Khattab.' Then I remembered `Umar's Ghaira (concerning women), and so I quickly went away from that palace." (When `Umar heard this from the Prophet), he wept and said, "Do you think it is likely that I feel Ghaira because of you, O Allah's Messenger (ﷺ)?}}
\hadithdefcmd{bukhari}{3243}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامٌ، قَالَ سَمِعْتُ أَبَا عِمْرَانَ الْجَوْنِيَّ، يُحَدِّثُ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ الأَشْعَرِيِّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْمَةُ دُرَّةٌ مُجَوَّفَةٌ، طُولُهَا فِي السَّمَاءِ ثَلاَثُونَ مِيلاً، فِي كُلِّ زَاوِيَةٍ مِنْهَا لِلْمُؤْمِنِ أَهْلٌ لاَ يَرَاهُمُ الآخَرُونَ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ الصَّمَدِ وَالْحَارِثُ بْنُ عُبَيْدٍ عَنْ أَبِي عِمْرَانَ سِتُّونَ مِيلاً‏.‏\hadithno{3243}\hadithtrans{Narrated `Abdullah bin Qais Al-Ash`ari:The Prophet (ﷺ) said, "A tent (in Paradise) is like a hollow pearl which is thirty miles in height and on every corner of the tent the believer will have a family that cannot be seen by the others." (Narrated Abu `Imran in another narration, "The tent is sixty miles in height)}}
\hadithdefcmd{bukhari}{3244}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَالَ اللَّهُ أَعْدَدْتُ لِعِبَادِي الصَّالِحِينَ مَا لاَ عَيْنَ رَأَتْ، وَلاَ أُذُنَ سَمِعَتْ، وَلاَ خَطَرَ عَلَى قَلْبِ بَشَرٍ، فَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏فَلاَ تَعْلَمُ نَفْسٌ مَا أُخْفِيَ لَهُمْ مِنْ قُرَّةِ أَعْيُنٍ ‏\}‏‏"‏‏.‏\hadithno{3244}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, "I have prepared for My Pious slaves things which have never been seen by an eye, or heard by an ear, or imagined by a human being." If you wish, you can recite this Verse from the Holy Qur'an:--"No soul knows what is kept hidden for them, of joy as a reward for what they used to do}}
\hadithdefcmd{bukhari}{3245}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ زُمْرَةٍ تَلِجُ الْجَنَّةَ صُورَتُهُمْ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ، لاَ يَبْصُقُونَ فِيهَا وَلاَ يَمْتَخِطُونَ وَلاَ يَتَغَوَّطُونَ، آنِيَتُهُمْ فِيهَا الذَّهَبُ، أَمْشَاطُهُمْ مِنَ الذَّهَبِ وَالْفِضَّةِ، وَمَجَامِرُهُمُ الأَلُوَّةُ، وَرَشْحُهُمُ الْمِسْكُ، وَلِكُلِّ وَاحِدٍ مِنْهُمْ زَوْجَتَانِ، يُرَى مُخُّ سُوقِهِمَا مِنْ وَرَاءِ اللَّحْمِ، مِنَ الْحُسْنِ، لاَ اخْتِلاَفَ بَيْنَهُمْ وَلاَ تَبَاغُضَ، قُلُوبُهُمْ قَلْبٌ وَاحِدٌ، يُسَبِّحُونَ اللَّهَ بُكْرَةً وَعَشِيًّا ‏"‏‏.‏\hadithno{3245}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The first group (of people) who will enter Paradise will be (glittering) like the moon when it is full. They will not spit or blow their noses or relieve nature. Their utensils will be of gold and their combs of gold and silver; in their centers the aloe wood will be used, and their sweat will smell like musk. Everyone of them will have two wives; the marrow of the bones of the wives' legs will be seen through the flesh out of excessive beauty. They ( i.e. the people of Paradise) will neither have differences nor hatred amongst themselves; their hearts will be as if one heart and they will be glorifying Allah in the morning and in the evening}}
\hadithdefcmd{bukhari}{3246}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَوَّلُ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ، وَالَّذِينَ عَلَى إِثْرِهِمْ كَأَشَدِّ كَوْكَبٍ إِضَاءَةً، قُلُوبُهُمْ عَلَى قَلْبِ رَجُلٍ وَاحِدٍ، لاَ اخْتِلاَفَ بَيْنَهُمْ وَلاَ تَبَاغُضَ، لِكُلِّ امْرِئٍ مِنْهُمْ زَوْجَتَانِ، كُلُّ وَاحِدَةٍ مِنْهُمَا يُرَى مُخُّ سَاقِهَا مِنْ وَرَاءِ لَحْمِهَا مِنَ الْحُسْنِ، يُسَبِّحُونَ اللَّهَ بُكْرَةً وَعَشِيًّا، لاَ يَسْقَمُونَ وَلاَ يَمْتَخِطُونَ، وَلاَ يَبْصُقُونَ، آنِيَتُهُمُ الذَّهَبُ وَالْفِضَّةُ، وَأَمْشَاطُهُمُ الذَّهَبُ، وَقُودُ مَجَامِرِهِمُ الأُلُوَّةُ ـ قَالَ أَبُو الْيَمَانِ يَعْنِي الْعُودَ ـ وَرَشْحُهُمُ الْمِسْكُ ‏"‏‏.‏ وَقَالَ مُجَاهِدٌ الإِبْكَارُ أَوَّلُ الْفَجْرِ، وَالْعَشِيُّ مَيْلُ الشَّمْسِ أَنْ تُرَاهُ تَغْرُبَ‏.‏\hadithno{3246}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The first batch (of people) who will enter Paradise will be (glittering) like a full moon; and those who will enter next will be (glittering) like the brightest star. Their hearts will be as if the heart of a single man, for they will have no enmity amongst themselves, and everyone of them shall have two wives, each of whom will be so beautiful, pure and transparent that the marrow of the bones of their legs will be seen through the flesh. They will be glorifying Allah in the morning and evening, and will never fall ill, and they will neither blow their noses, nor spit. Their utensils will be of gold and silver, and their combs will be of gold, and the fuel used in their centers will be the aloeswood, and their sweat will smell like musk}}
\hadithdefcmd{bukhari}{3247}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَيَدْخُلَنَّ مِنْ أُمَّتِي سَبْعُونَ أَلْفًا ـ أَوْ سَبْعُمِائَةِ أَلْفٍ ـ لاَ يَدْخُلُ أَوَّلُهُمْ حَتَّى يَدْخُلَ آخِرُهُمْ، وَجُوهُهُمْ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏\hadithno{3247}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "Verily! 70,000 or 700,000 of my followers will enter Paradise altogether; so that the first and the last amongst them will enter at the same time, and their faces will be glittering like the bright full moon}}
\hadithdefcmd{bukhari}{3248}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الْجُعْفِيُّ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ قَالَ أُهْدِيَ لِلنَّبِيِّ صلى الله عليه وسلم جُبَّةُ سُنْدُسٍ، وَكَانَ يَنْهَى عَنِ الْحَرِيرِ، فَعَجِبَ النَّاسُ مِنْهَا، فَقَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ، لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَحْسَنُ مِنْ هَذَا ‏"‏‏.‏\hadithno{3248}\hadithtrans{Narrated Anas bin Malik:A silken cloak was presented to the Prophet (ﷺ) and he used to forbid the usage of silk (by men). When the people were fascinated by the cloak. he said, "By Allah in Whose Hands the life of Muhammad is, the handkerchiefs of Sa`d bin Mu`adh in Paradise are better than this}}
\hadithdefcmd{bukhari}{3249}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِثَوْبٍ مِنْ حَرِيرٍ، فَجَعَلُوا يَعْجَبُونَ مِنْ حُسْنِهِ وَلِينِهِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَفْضَلُ مِنْ هَذَا ‏"‏‏.‏\hadithno{3249}\hadithtrans{Narrated Al-Bara bin Azib:Allah's Messenger (ﷺ) was given a silken garment, and its beauty and delicacy astonished the people. On that, Allah's Messenger (ﷺ) said, "No doubt, the handkerchiefs of Sa`d bin Mu`adh in Paradise are better than this}}
\hadithdefcmd{bukhari}{3250}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَوْضِعُ سَوْطٍ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏\hadithno{3250}\hadithtrans{Narrated Sahl bin Sa`d Al-Saidi:Allah's Messenger (ﷺ) said, "A place in Paradise equal to the size of a lash is better than the whole world and whatever is in it}}
\hadithdefcmd{bukhari}{3251}{حَدَّثَنَا رَوْحُ بْنُ عَبْدِ الْمُؤْمِنِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ لاَ يَقْطَعُهَا ‏"‏‏.‏\hadithno{3251}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "There is a tree in Paradise (which is so big and huge that) if a rider travels in its shade for one hundred years, he would not be able to cross it}}
\hadithdefcmd{bukhari}{3253}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ سَنَةٍ، وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏وَظِلٍّ مَمْدُودٍ‏\}‏‏"‏ «وَلَقَابُ قَوْسِ أَحَدِكُمْ فِي الْجَنَّةِ خَيْرٌ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ أَوْ تَغْرُبُ»\hadithno{3253}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said "There is a tree in Paradise (which is so big and huge that) a rider could travel in its shade for a hundred years. And if you wish, you can recite:--'In shade long extended..' (56. 30) and a place in Paradise equal to an arrow bow of one of you, is better than (the whole earth) on which the sun rises and sets}}
\hadithdefcmd{bukhari}{3254}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، حَدَّثَنَا أَبِي، عَنْ هِلاَلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَوَّلُ زُمْرَةٍ تَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ، وَالَّذِينَ عَلَى آثَارِهِمْ كَأَحْسَنِ كَوْكَبٍ دُرِّيٍّ فِي السَّمَاءِ إِضَاءَةً، قُلُوبُهُمْ عَلَى قَلْبِ رَجُلٍ وَاحِدٍ، لاَ تَبَاغُضَ بَيْنَهُمْ وَلاَ تَحَاسُدَ، لِكُلِّ امْرِئٍ زَوْجَتَانِ مِنَ الْحُورِ الْعِينِ، يُرَى مُخُّ سُوقِهِنَّ مِنْ وَرَاءِ الْعَظْمِ وَاللَّحْمِ ‏"‏‏.‏\hadithno{3254}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The first batch (of people) who will enter Paradise will be (glittering) like the full moon, and the batch next to them will be (glittering) like the most brilliant star in the sky. Their hearts will be as if the heart of a single man, for they will have neither enmity nor jealousy amongst themselves; everyone will have two wives from the houris, (who will be so beautiful, pure and transparent that) the marrow of the bones of their legs will be seen through the bones and the flesh}}
\hadithdefcmd{bukhari}{3255}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ عَدِيُّ بْنُ ثَابِتٍ أَخْبَرَنِي قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ لَمَّا مَاتَ إِبْرَاهِيمُ قَالَ ‏ "‏ إِنَّ لَهُ مُرْضِعًا فِي الْجَنَّةِ ‏"‏‏.‏\hadithno{3255}\hadithtrans{Narrated Al-Bara (bin Azib):The Prophet, after the death of his son Ibrahim, said, "There is a wet-nurse for him (i.e. Ibrahim) in Paradise}}
\hadithdefcmd{bukhari}{3256}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ يَتَرَاءَيُونَ أَهْلَ الْغُرَفِ مِنْ فَوْقِهِمْ كَمَا يَتَرَاءَيُونَ الْكَوْكَبَ الدُّرِّيَّ الْغَابِرَ فِي الأُفُقِ مِنَ الْمَشْرِقِ أَوِ الْمَغْرِبِ، لِتَفَاضُلِ مَا بَيْنَهُمْ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، تِلْكَ مَنَازِلُ الأَنْبِيَاءِ لاَ يَبْلُغُهَا غَيْرُهُمْ قَالَ ‏"‏ بَلَى وَالَّذِي نَفْسِي بِيَدِهِ، رِجَالٌ آمَنُوا بِاللَّهِ وَصَدَّقُوا الْمُرْسَلِينَ ‏"‏‏.‏\hadithno{3256}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "The people of Paradise will look at the dwellers of the lofty mansions (i.e. a superior place in Paradise) in the same way as one looks at a brilliant star far away in the East or in the West on the horizon; all that is because of their superiority over one another (in rewards)." On that the people said, "O Allah's Messenger (ﷺ)! Are these lofty mansions for the prophets which nobody else can reach? The Prophet (ﷺ) replied," No! "By Allah in whose Hands my life is, these are for the men who believed in Allah and also believed in the Apostles}}
\hadithdefcmd{bukhari}{3257}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُطَرِّفٍ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْجَنَّةِ ثَمَانِيَةُ أَبْوَابٍ، فِيهَا باب يُسَمَّى الرَّيَّانَ لاَ يَدْخُلُهُ إِلاَّ الصَّائِمُونَ ‏"‏‏.‏\hadithno{3257}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "Paradise has eight gates, and one of them is called Ar-Raiyan through which none will enter but those who observe fasting}}
\hadithdefcmd{bukhari}{3258}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ مُهَاجِرٍ أَبِي الْحَسَنِ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، يَقُولُ سَمِعْتُ أَبَا ذَرٍّ ـ رضى الله عنه ـ يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي سَفَرٍ فَقَالَ ‏"‏ أَبْرِدْ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ أَبْرِدْ ‏"‏‏.‏ حَتَّى فَاءَ الْفَىْءُ، يَعْنِي لِلتُّلُولِ، ثُمَّ قَالَ ‏"‏ أَبْرِدُوا بِالصَّلاَةِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏\hadithno{3258}\hadithtrans{Narrated Abu Dhar:While the Prophet (ﷺ) was on a journey, he said (regarding the performance of the Zuhr prayer), "Wait till it (i.e. the weather) gets cooler." He said the same again till the shade of the hillocks extended. Then he said, "Delay the (Zuhr) Prayer till it gets cooler, for the severity of heat is from the increase in heat of Hell (fire)}}
\hadithdefcmd{bukhari}{3259}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ، رضى الله عنه قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَبْرِدُوا بِالصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏\hadithno{3259}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Delay the (Zuhr) Prayer till it gets cooler, for the severity of heat is from the increase in the heat of Hell (fire)}}
\hadithdefcmd{bukhari}{3260}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْتَكَتِ النَّارُ إِلَى رَبِّهَا، فَقَالَتْ رَبِّ أَكَلَ بَعْضِي بَعْضًا، فَأَذِنَ لَهَا بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ، فَأَشَدُّ مَا تَجِدُونَ فِي الْحَرِّ، وَأَشَدُّ مَا تَجِدُونَ مِنَ الزَّمْهَرِيرِ ‏"‏‏.‏\hadithno{3260}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The (Hell) Fire complained to its Lord saying, 'O my Lord! My different parts eat up each other.' So, He allowed it to take two breaths, one in the winter and the other in summer, and this is the reason for the severe heat and the bitter cold you find (in weather)}}
\hadithdefcmd{bukhari}{3261}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ أَبِي جَمْرَةَ الضُّبَعِيِّ، قَالَ كُنْتُ أُجَالِسُ ابْنَ عَبَّاسٍ بِمَكَّةَ، فَأَخَذَتْنِي الْحُمَّى، فَقَالَ أَبْرِدْهَا عَنْكَ بِمَاءِ زَمْزَمَ، فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَبْرِدُوهَا بِالْمَاءِ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ بِمَاءِ زَمْزَمَ ‏"‏‏.‏ شَكَّ هَمَّامٌ‏.‏\hadithno{3261}\hadithtrans{Narrated Abu Jamra Ad-Dabi:I used to sit with Ibn `Abbas in Mecca. Once I had a fever and he said (to me), "Cool your fever with Zamzam water, for Allah's Messenger (ﷺ) said: 'It, (the Fever) is from the heat of the (Hell) Fire; so, cool it with water (or Zamzam water)}}
\hadithdefcmd{bukhari}{3262}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، قَالَ أَخْبَرَنِي رَافِعُ بْنُ خَدِيجٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْحُمَّى مِنْ فَوْرِ جَهَنَّمَ، فَأَبْرِدُوهَا عَنْكُمْ بِالْمَاءِ ‏"‏‏.‏\hadithno{3262}\hadithtrans{Narrated Rafi` bin Khadij:I heard the Prophet (ﷺ) saying, "Fever is from the heat of the (Hell) Fire; so cool it with water}}
\hadithdefcmd{bukhari}{3263}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا هِشَامٌ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ، فَأَبْرِدُوهَا بِالْمَاءِ ‏"‏‏.‏\hadithno{3263}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) said, "Fever is from the heat of the (Hell) Fire, so cool it with water}}
\hadithdefcmd{bukhari}{3264}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَبْرِدُوهَا بِالْمَاءِ ‏"‏‏.‏\hadithno{3264}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Fever is from the heat of the (Hell) Fire; so abate fever with water}}
\hadithdefcmd{bukhari}{3265}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ نَارُكُمْ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنْ نَارِ جَهَنَّمَ ‏"‏‏.‏ قِيلَ يَا رَسُولَ اللَّهِ، إِنْ كَانَتْ لَكَافِيَةً‏.‏ قَالَ ‏"‏ فُضِّلَتْ عَلَيْهِنَّ بِتِسْعَةٍ وَسِتِّينَ جُزْءًا، كُلُّهُنَّ مِثْلُ حَرِّهَا ‏"‏‏.‏\hadithno{3265}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Your (ordinary) fire is one of 70 parts of the (Hell) Fire." Someone asked, "O Allah's Messenger (ﷺ) This (ordinary) fire would have been sufficient (to torture the unbelievers)," Allah's Apostle said, "The (Hell) Fire has 69 parts more than the ordinary (worldly) fire, each part is as hot as this (worldly) fire}}
\hadithdefcmd{bukhari}{3266}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ عَطَاءً، يُخْبِرُ عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏\{‏وَنَادَوْا يَا مَالِكُ ‏\}‏‏.‏\hadithno{3266}\hadithtrans{Narrated Yali:That he heard the Prophet (ﷺ) on the pulpit reciting:-- "They will cry: "O Malik!' (43.77) (Malik is the gate-keeper (angel) of the (Hell) Fire}}
\hadithdefcmd{bukhari}{3267}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ،، قَالَ قِيلَ لأُسَامَةَ لَوْ أَتَيْتَ فُلاَنًا فَكَلَّمْتَهُ‏.‏ قَالَ إِنَّكُمْ لَتَرَوْنَ أَنِّي لاَ أُكَلِّمُهُ إِلاَّ أُسْمِعُكُمْ، إِنِّي أُكُلِّمُهُ فِي السِّرِّ دُونَ أَنْ أَفْتَحَ بَابًا لاَ أَكُونُ أَوَّلَ مَنْ فَتَحَهُ، وَلاَ أَقُولُ لِرَجُلٍ أَنْ كَانَ عَلَىَّ أَمِيرًا إِنَّهُ خَيْرُ النَّاسِ بَعْدَ شَىْءٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالُوا وَمَا سَمِعْتَهُ يَقُولُ قَالَ سَمِعْتُهُ يَقُولُ ‏ "‏ يُجَاءُ بِالرَّجُلِ يَوْمَ الْقِيَامَةِ فَيُلْقَى فِي النَّارِ، فَتَنْدَلِقُ أَقْتَابُهُ فِي النَّارِ، فَيَدُورُ كَمَا يَدُورُ الْحِمَارُ بِرَحَاهُ، فَيَجْتَمِعُ أَهْلُ النَّارِ عَلَيْهِ، فَيَقُولُونَ أَىْ فُلاَنُ، مَا شَأْنُكَ أَلَيْسَ كُنْتَ تَأْمُرُنَا بِالْمَعْرُوفِ وَتَنْهَى عَنِ الْمُنْكَرِ قَالَ كُنْتُ آمُرُكُمْ بِالْمَعْرُوفِ وَلاَ آتِيهِ، وَأَنْهَاكُمْ عَنِ الْمُنْكَرِ وَآتِيهِ ‏"‏‏.‏ رَوَاهُ غُنْدَرٌ عَنْ شُعْبَةَ عَنِ الأَعْمَشِ‏.‏\hadithno{3267}\hadithtrans{Narrated Abu Wail:Somebody said to Usama, "Will you go to so-and-so (i.e. `Uthman) and talk to him (i.e. advise him regarding ruling the country)?" He said, "You see that I don't talk to him. Really I talk to (advise) him secretly without opening a gate (of affliction), for neither do I want to be the first to open it (i.e. rebellion), nor will I say to a man who is my ruler that he is the best of all the people after I have heard something from Allah's Apostle ." They said, What have you heard him saying? He said, "I have heard him saying, "A man will be brought on the Day of Resurrection and thrown in the (Hell) Fire, so that his intestines will come out, and he will go around like a donkey goes around a millstone. The people of (Hell) Fire will gather around him and say: O so-and-so! What is wrong with you? Didn't you use to order us to do good deeds and forbid us to do bad deeds? He will reply: Yes, I used to order you to do good deeds, but I did not do them myself, and I used to forbid you to do bad deeds, yet I used to do them myself}}
\hadithdefcmd{bukhari}{3268}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سُحِرَ النَّبِيُّ صلى الله عليه وسلم‏.‏ وَقَالَ اللَّيْثُ كَتَبَ إِلَىَّ هِشَامٌ أَنَّهُ سَمِعَهُ وَوَعَاهُ عَنْ أَبِيهِ عَنْ عَائِشَةَ قَالَتْ سُحِرَ النَّبِيُّ صلى الله عليه وسلم حَتَّى كَانَ يُخَيَّلُ إِلَيْهِ أَنَّهُ يَفْعَلُ الشَّىْءَ وَمَا يَفْعَلُهُ، حَتَّى كَانَ ذَاتَ يَوْمٍ دَعَا وَدَعَا، ثُمَّ قَالَ ‏"‏ أَشَعَرْتِ أَنَّ اللَّهَ أَفْتَانِي فِيمَا فِيهِ شِفَائِي أَتَانِي رَجُلاَنِ، فَقَعَدَ أَحَدُهُمَا عِنْدَ رَأْسِي وَالآخَرُ عِنْدَ رِجْلَىَّ، فَقَالَ أَحَدُهُمَا لِلآخَرِ مَا وَجَعُ الرَّجُلِ قَالَ مَطْبُوبٌ‏.‏ قَالَ وَمَنْ طَبَّهُ قَالَ لَبِيدُ بْنُ الأَعْصَمِ‏.‏ قَالَ فِي مَاذَا قَالَ فِي مُشُطٍ وَمُشَاقَةٍ وَجُفِّ طَلْعَةٍ ذَكَرٍ‏.‏ قَالَ فَأَيْنَ هُوَ قَالَ فِي بِئْرِ ذَرْوَانَ ‏"‏‏.‏ فَخَرَجَ إِلَيْهَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ رَجَعَ فَقَالَ لِعَائِشَةَ حِينَ رَجَعَ ‏"‏ نَخْلُهَا كَأَنَّهَا رُءُوسُ الشَّيَاطِينِ ‏"‏‏.‏ فَقُلْتُ اسْتَخْرَجْتَهُ فَقَالَ ‏"‏ لاَ أَمَّا أَنَا فَقَدْ شَفَانِي اللَّهُ، وَخَشِيتُ أَنْ يُثِيرَ ذَلِكَ عَلَى النَّاسِ شَرًّا، ثُمَّ دُفِنَتِ الْبِئْرُ ‏"‏‏.‏\hadithno{3268}\hadithtrans{Narrated `Aisha:Magic was worked on the Prophet (ﷺ) so that he began to fancy that he was doing a thing which he was not actually doing. One day he invoked (Allah) for a long period and then said, "I feel that Allah has inspired me as how to cure myself. Two persons came to me (in my dream) and sat, one by my head and the other by my feet. One of them asked the other, "What is the ailment of this man?" The other replied, 'He has been bewitched" The first asked, 'Who has bewitched him?' The other replied, 'Labid bin Al-A'sam.' The first one asked, 'What material has he used?' The other replied, 'A comb, the hair gathered on it, and the outer skin of the pollen of the male date-palm.' The first asked, 'Where is that?' The other replied, 'It is in the well of Dharwan.' " So, the Prophet (ﷺ) went out towards the well and then returned and said to me on his return, "Its date-palms (the date-palms near the well) are like the heads of the devils." I asked, "Did you take out those things with which the magic was worked?" He said, "No, for I have been cured by Allah and I am afraid that this action may spread evil amongst the people." Later on the well was filled up with earth}}
\hadithdefcmd{bukhari}{3269}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ إِذَا هُوَ نَامَ ثَلاَثَ عُقَدٍ، يَضْرِبُ كُلَّ عُقْدَةٍ مَكَانَهَا عَلَيْكَ لَيْلٌ طَوِيلٌ فَارْقُدْ‏.‏ فَإِنِ اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ، فَإِنْ تَوَضَّأَ انْحَلَّتْ عُقْدَةٌ، فَإِنْ صَلَّى انْحَلَّتْ عُقَدُهُ كُلُّهَا، فَأَصْبَحَ نَشِيطًا طَيِّبَ النَّفْسِ، وَإِلاَّ أَصْبَحَ خَبِيثَ النَّفْسِ كَسْلاَنَ ‏"‏‏.‏\hadithno{3269}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "During your sleep, Satan knots three knots at the back of the head of each of you, and he breathes the following words at each knot, 'The night is, long, so keep on sleeping,' If that person wakes up and celebrates the praises of Allah, then one knot is undone, and when he performs ablution the second knot is undone, and when he prays, all the knots are undone, and he gets up in the morning lively and in good spirits, otherwise he gets up in low spirits and lethargic}}
\hadithdefcmd{bukhari}{3270}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ ذُكِرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم رَجُلٌ نَامَ لَيْلَهُ حَتَّى أَصْبَحَ، قَالَ ‏ "‏ ذَاكَ رَجُلٌ بَالَ الشَّيْطَانُ فِي أُذُنَيْهِ ـ أَوْ قَالَ ـ فِي أُذُنِهِ ‏"‏‏.‏\hadithno{3270}\hadithtrans{Narrated `Abdullah:It was mentioned before the Prophet (ﷺ) that there was a man who slept the night till morning (after sunrise). The Prophet (ﷺ) said, "He is a man in whose ears (or ear) Satan had urinated}}
\hadithdefcmd{bukhari}{3271}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَمَا إِنَّ أَحَدَكُمْ إِذَا أَتَى أَهْلَهُ وَقَالَ بِسْمِ اللَّهِ اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ، وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا‏.‏ فَرُزِقَا وَلَدًا، لَمْ يَضُرُّهُ الشَّيْطَانُ ‏"‏‏.‏\hadithno{3271}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If anyone of you, when having sexual relation with his wife, say: 'In the name of Allah. O Allah! Protect us from Satan and prevent Satan from approaching our offspring you are going to give us,' and if he begets a child (as a result of that relation) Satan will not harm it}}
\hadithdefcmd{bukhari}{3273}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا طَلَعَ حَاجِبُ الشَّمْسِ فَدَعُوا الصَّلاَةَ حَتَّى تَبْرُزَ، وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَدَعُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏‏.‏ ‏"‏ وَلاَ تَحَيَّنُوا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا، فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ ‏"‏‏.‏ أَوِ الشَّيْطَانِ‏.‏ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَ هِشَامٌ‏.‏\hadithno{3273}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "When the (upper) edge of the sun appears (in the morning), don't perform a prayer till the sun appears in full, and when the lower edge of the sun sets, don't perform a prayer till it sets completely. And you should not seek to pray at sunrise or sunset for the sun rises between two sides of the head of the devil (or Satan)}}
\hadithdefcmd{bukhari}{3274}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا يُونُسُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا مَرَّ بَيْنَ يَدَىْ أَحَدِكُمْ شَىْءٌ وَهُوَ يُصَلِّي فَلْيَمْنَعْهُ، فَإِنْ أَبَى فَلْيَمْنَعْهُ، فَإِنْ أَبَى فَلْيُقَاتِلْهُ، فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏‏.‏\hadithno{3274}\hadithtrans{Narrated Abu Said Al-Khudri: The Prophet (ﷺ) said, "If while you are praying, somebody intends to pass in front of you, prevent him; and should he insist, prevent him again; and if he insists again, fight with him (i.e. prevent him violently e.g. pushing him violently), because such a person is (like) a devil}}
\hadithdefcmd{bukhari}{3275}{وَقَالَ عُثْمَانُ بْنُ الْهَيْثَمِ حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ وَكَّلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِحِفْظِ زَكَاةِ رَمَضَانَ، فَأَتَانِي آتٍ، فَجَعَلَ يَحْثُو مِنَ الطَّعَامِ، فَأَخَذْتُهُ فَقُلْتُ لأَرْفَعَنَّكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَذَكَرَ الْحَدِيثَ فَقَالَ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَاقْرَأْ آيَةَ الْكُرْسِيِّ لَنْ يَزَالَ عَلَيْكَ مِنَ اللَّهِ حَافِظٌ، وَلاَ يَقْرَبُكَ شَيْطَانٌ حَتَّى تُصْبِحَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَدَقَكَ وَهْوَ كَذُوبٌ، ذَاكَ شَيْطَانٌ ‏"‏‏.‏\hadithno{3275}\hadithtrans{Narrated Muhammad bin Sirin:Abu Huraira said, "Allah's Messenger (ﷺ) put me in charge of the Zakat of Ramadan (i.e. Zakat-ul-Fitr). Someone came to me and started scooping some of the foodstuff of (Zakat) with both hands. I caught him and told him that I would take him to Allah's Messenger (ﷺ)." Then Abu Huraira told the whole narration and added "He (i.e. the thief) said, 'Whenever you go to your bed, recite the Verse of "Al-Kursi" (2.255) for then a guardian from Allah will be guarding you, and Satan will not approach you till dawn.' " On that the Prophet (ﷺ) said, "He told you the truth, though he is a liar, and he (the thief) himself was the Satan}}
\hadithdefcmd{bukhari}{3276}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي الشَّيْطَانُ أَحَدَكُمْ فَيَقُولُ مَنْ خَلَقَ كَذَا مَنْ خَلَقَ كَذَا حَتَّى يَقُولَ مَنْ خَلَقَ رَبَّكَ فَإِذَا بَلَغَهُ فَلْيَسْتَعِذْ بِاللَّهِ، وَلْيَنْتَهِ ‏"‏‏.‏\hadithno{3276}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Satan comes to one of you and says, 'Who created so-and-so? 'till he says, 'Who has created your Lord?' So, when he inspires such a question, one should seek refuge with Allah and give up such thoughts}}
\hadithdefcmd{bukhari}{3277}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي ابْنُ أَبِي أَنَسٍ، مَوْلَى التَّيْمِيِّينَ أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ، وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ، وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏‏.‏\hadithno{3277}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the month of Ramadan comes, the gates of Paradise are opened and the gates of the (Hell) Fire are closed, and the devils are chained}}
\hadithdefcmd{bukhari}{3278}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ فَقَالَ حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مُوسَى قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا، قَالَ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ، فَإِنِّي نَسِيتُ الْحُوتَ، وَمَا أَنْسَانِيهِ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ، وَلَمْ يَجِدْ مُوسَى النَّصَبَ حَتَّى جَاوَزَ الْمَكَانَ الَّذِي أَمَرَ اللَّهُ بِهِ ‏"‏‏.‏\hadithno{3278}\hadithtrans{Narrated Ubai bin Ka`b:That he heard Allah's Messenger (ﷺ) saying, "(The prophet) Moses said to his attendant, "Bring us our early meal' (18.62). The latter said, 'Did you remember when we betook ourselves to the rock? I indeed forgot the fish and none but Satan made me forget to remember it." (18.63) Moses did not feel tired till he had crossed the place which Allah ordered him to go to}}
\hadithdefcmd{bukhari}{3279}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُشِيرُ إِلَى الْمَشْرِقِ فَقَالَ ‏ "‏ هَا إِنَّ الْفِتْنَةَ هَا هُنَا إِنَّ الْفِتْنَةَ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏‏.‏\hadithno{3279}\hadithtrans{Narrated `Abdullah bin `Umar:I saw Allah's Messenger (ﷺ) pointing towards the east saying, "Lo! Afflictions will verily emerge hence; afflictions will verily emerge hence where the (side of the head of) Satan appears}}
\hadithdefcmd{bukhari}{3280}{حَدَّثَنَا يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَجْنَحَ ‏\{‏اللَّيْلُ‏\}‏ ـ أَوْ كَانَ جُنْحُ اللَّيْلِ ـ فَكُفُّوا صِبْيَانَكُمْ، فَإِنَّ الشَّيَاطِينَ تَنْتَشِرُ حِينَئِذٍ، فَإِذَا ذَهَبَ سَاعَةٌ مِنَ الْعِشَاءِ فَحُلُّوهُمْ وَأَغْلِقْ بَابَكَ، وَاذْكُرِ اسْمَ اللَّهِ، وَأَطْفِئْ مِصْبَاحَكَ، وَاذْكُرِ اسْمَ اللَّهِ، وَأَوْكِ سِقَاءَكَ، وَاذْكُرِ اسْمَ اللَّهِ، وَخَمِّرْ إِنَاءَكَ، وَاذْكُرِ اسْمَ اللَّهِ، وَلَوْ تَعْرُضُ عَلَيْهِ شَيْئًا ‏"‏‏.‏\hadithno{3280}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "When night falls, then keep your children close to you, for the devils spread out then. An hour later you can let them free; and close the gates of your house (at night), and mention Allah's Name thereupon, and cover your utensils, and mention Allah's Name thereupon, (and if you don't have something to cover your utensil) you may put across it something (e.g. a piece of wood etc)}}
\hadithdefcmd{bukhari}{3281}{حَدَّثَنِي مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ صَفِيَّةَ ابْنَةِ حُيَىٍّ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُعْتَكِفًا، فَأَتَيْتُهُ أَزُورُهُ لَيْلاً فَحَدَّثْتُهُ ثُمَّ قُمْتُ، فَانْقَلَبْتُ فَقَامَ مَعِي لِيَقْلِبَنِي‏.‏ وَكَانَ مَسْكَنُهَا فِي دَارِ أُسَامَةَ بْنِ زَيْدٍ، فَمَرَّ رَجُلاَنِ مِنَ الأَنْصَارِ، فَلَمَّا رَأَيَا النَّبِيَّ صلى الله عليه وسلم أَسْرَعَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكُمَا إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏‏.‏ فَقَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ، وَإِنِّي خَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا سُوءًا ـ أَوْ قَالَ ـ شَيْئًا ‏"‏‏.‏\hadithno{3281}\hadithtrans{Narrated Safiya bint Huyay:While Allah's Messenger (ﷺ) was in I`tikaf, I called on him at night and having had a talk with him, I got up to depart. He got up also to accompany me to my dwelling place, which was then in the house of Usama bin Zaid. Two Ansari men passed by, and when they saw the Prophet (ﷺ) they hastened away. The Prophet said (to them). "Don't hurry! It is Safiya, the daughter of Huyay (i.e. my wife)." They said, "Glorified be Allah! O Allah's Messenger (ﷺ)! (How dare we suspect you?)" He said, "Satan circulates in the human mind as blood circulates in it, and I was afraid that Satan might throw an evil thought (or something) into your hearts}}
\hadithdefcmd{bukhari}{3282}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، قَالَ كُنْتُ جَالِسًا مَعَ النَّبِيِّ صلى الله عليه وسلم وَرَجُلاَنِ يَسْتَبَّانِ، فَأَحَدُهُمَا احْمَرَّ وَجْهُهُ وَانْتَفَخَتْ أَوْدَاجُهُ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي لأَعْلَمُ كَلِمَةً لَوْ قَالَهَا ذَهَبَ عَنْهُ مَا يَجِدُ، لَوْ قَالَ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ‏.‏ ذَهَبَ عَنْهُ مَا يَجِدُ ‏"‏‏.‏ فَقَالُوا لَهُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ تَعَوَّذْ بِاللَّهِ مِنَ الشَّيْطَانِ ‏"‏‏.‏ فَقَالَ وَهَلْ بِي جُنُونٌ\hadithno{3282}\hadithtrans{Narrated Sulaiman bin Surad:While I was sitting in the company of the Prophet, two men abused each other and the face of one of them became red with anger, and his jugular veins swelled (i.e. he became furious). On that the Prophet said, "I know a word, the saying of which will cause him to relax, if he does say it. If he says: 'I seek Refuge with Allah from Satan.' then all his anger will go away." Somebody said to him, "The Prophet has said, 'Seek refuge with Allah from Satan."' The angry man said, "Am I mad?}}
\hadithdefcmd{bukhari}{3283}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا مَنْصُورٌ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَتَى أَهْلَهُ قَالَ ‏\{‏اللَّهُمَّ‏\}‏ جَنِّبْنِي الشَّيْطَانَ، وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنِي‏.‏ فَإِنْ كَانَ بَيْنَهُمَا وَلَدٌ لَمْ يَضُرُّهُ الشَّيْطَانُ، وَلَمْ يُسَلَّطْ عَلَيْهِ ‏"‏‏.‏ قَالَ وَحَدَّثَنَا الأَعْمَشُ عَنْ سَالِمٍ عَنْ كُرَيْبٍ عَنِ ابْنِ عَبَّاسٍ مِثْلَهُ‏.‏\hadithno{3283}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "If anyone of you, on having sexual relation with his wife, says: 'O Allah! Protect me from Satan, and prevent Satan from approaching the offspring you are going to give me,' and if it happens that the lady conceives a child, Satan will neither harm it nor be given power over it}}
\hadithdefcmd{bukhari}{3284}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةً فَقَالَ ‏ "‏ إِنَّ الشَّيْطَانَ عَرَضَ لِي، فَشَدَّ عَلَىَّ يَقْطَعُ الصَّلاَةَ عَلَىَّ، فَأَمْكَنَنِي اللَّهُ مِنْهُ ‏"‏‏.‏ فَذَكَرَهُ‏.‏\hadithno{3284}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) offered a prayer, and (after finishing) he said, "Satan came in front of me trying persistently to divert my attention from the prayer, but Allah gave me the strength to over-power him}}
\hadithdefcmd{bukhari}{3285}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا نُودِيَ بِالصَّلاَةِ أَدْبَرَ الشَّيْطَانُ وَلَهُ ضُرَاطٌ، فَإِذَا قُضِيَ أَقْبَلَ، فَإِذَا ثُوِّبَ بِهَا أَدْبَرَ، فَإِذَا قُضِيَ أَقْبَلَ، حَتَّى يَخْطِرَ بَيْنَ الإِنْسَانِ وَقَلْبِهِ، فَيَقُولُ اذْكُرْ كَذَا وَكَذَا‏.‏ حَتَّى لاَ يَدْرِي أَثَلاَثًا صَلَّى أَمْ أَرْبَعًا فَإِذَا لَمْ يَدْرِ ثَلاَثًا صَلَّى أَوْ أَرْبَعًا سَجَدَ سَجْدَتَىِ السَّهْوِ ‏"‏‏.‏\hadithno{3285}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When the call for the prayer is pronounced, Satan takes to his heels, passing wind with noise, When the call for the prayer is finished, he comes back. And when the Iqama is pronounced, he again takes to his heels, and after its completion, he returns again to interfere between the (praying) person and his heart, saying to him. 'Remember this or that thing.' till the person forgets whether he has offered three or four rak`at: so if one forgets whether he has prayed three or four rak`at, he should perform two prostrations of Sahu (i.e. forgetfulness)}}
\hadithdefcmd{bukhari}{3286}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُّ بَنِي آدَمَ يَطْعُنُ الشَّيْطَانُ فِي جَنْبَيْهِ بِإِصْبَعِهِ حِينَ يُولَدُ، غَيْرَ عِيسَى بْنِ مَرْيَمَ، ذَهَبَ يَطْعُنُ فَطَعَنَ فِي الْحِجَابِ ‏"‏‏.‏\hadithno{3286}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When any human being is born. Satan touches him at both sides of the body with his two fingers, except Jesus, the son of Mary, whom Satan tried to touch but failed, for he touched the placenta-cover instead}}
\hadithdefcmd{bukhari}{3287}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنِ الْمُغِيرَةِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ قَدِمْتُ الشَّأْمَ ‏\{‏فَقُلْتُ مَنْ هَا هُنَا‏\}‏ قَالُوا أَبُو الدَّرْدَاءِ قَالَ أَفِيكُمُ الَّذِي أَجَارَهُ اللَّهُ مِنَ الشَّيْطَانِ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ حَدَّثَنَا شُعْبَةُ عَنْ مُغِيرَةَ وَقَالَ الَّذِي أَجَارَهُ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم يَعْنِي عَمَّارًا‏.‏\hadithno{3287}\hadithtrans{Narrated Alqama:I went to Sham (and asked. "Who is here?"), The people said, "Abu Ad-Darda." Abu Darda said, "Is the person whom Allah has protected against Satan, (as Allah's Messenger (ﷺ) said) amongst you". The subnarrator, Mughira said that the person who was given Allah's Refuge through the tongue of the Prophet was `Ammar (bin Yasir)}}
\hadithdefcmd{bukhari}{3288}{قَالَ وَقَالَ اللَّيْثُ حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، أَنَّ أَبَا الأَسْوَدِ، أَخْبَرَهُ عُرْوَةُ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَلاَئِكَةُ تَتَحَدَّثُ فِي الْعَنَانِ ـ وَالْعَنَانُ الْغَمَامُ ـ بِالأَمْرِ يَكُونُ فِي الأَرْضِ، فَتَسْمَعُ الشَّيَاطِينُ الْكَلِمَةَ، فَتَقُرُّهَا فِي أُذُنِ الْكَاهِنِ، كَمَا تُقَرُّ الْقَارُورَةُ، فَيَزِيدُونَ مَعَهَا مِائَةَ كَذِبَةٍ ‏"‏‏.‏\hadithno{3288}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "While the angels talk amidst the clouds about things that are going to happen on earth, the devils hear a word of what they say and pour it in the ears of a soothsayer as one pours something in a bottle, and they add one hundred lies to that (one word)}}
\hadithdefcmd{bukhari}{3289}{حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ التَّثَاؤُبُ مِنَ الشَّيْطَانِ، فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَرُدَّهُ مَا اسْتَطَاعَ، فَإِنَّ أَحَدَكُمْ إِذَا قَالَ هَا‏.‏ ضَحِكَ الشَّيْطَانُ ‏"‏‏.‏\hadithno{3289}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Yawning is from Satan and if anyone of you yawns, he should check his yawning as much as possible, for if anyone of you (during the act of yawning) should say: 'Ha', Satan will laugh at him}}
\hadithdefcmd{bukhari}{3290}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ هِشَامٌ أَخْبَرَنَا عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ لَمَّا كَانَ يَوْمَ أُحُدٍ هُزِمَ الْمُشْرِكُونَ فَصَاحَ إِبْلِيسُ أَىْ عِبَادَ اللَّهِ أُخْرَاكُمْ‏.‏ فَرَجَعَتْ أُولاَهُمْ فَاجْتَلَدَتْ هِيَ وَأُخْرَاهُمْ، فَنَظَرَ حُذَيْفَةُ فَإِذَا هُوَ بِأَبِيهِ الْيَمَانِ فَقَالَ أَىْ عِبَادَ اللَّهِ أَبِي أَبِي‏.‏ فَوَاللَّهِ مَا احْتَجَزُوا حَتَّى قَتَلُوهُ، فَقَالَ حُذَيْفَةُ غَفَرَ اللَّهُ لَكُمْ‏.‏ قَالَ عُرْوَةُ فَمَا زَالَتْ فِي حُذَيْفَةَ مِنْهُ بَقِيَّةُ خَيْرٍ حَتَّى لَحِقَ بِاللَّهِ‏.‏\hadithno{3290}\hadithtrans{Narrated `Aisha:On the day (of the battle) of Uhud when the pagans were defeated, Satan shouted, "O slaves of Allah! Beware of the forces at your back," and on that the Muslims of the front files fought with the Muslims of the back files (thinking they were pagans). Hudhaifa looked back to see his father "Al-Yaman," (being attacked by the Muslims). He shouted, "O Allah's Slaves! My father! My father!" By Allah, they did not stop till they killed him. Hudhaifa said, "May Allah forgive you." `Urwa said that Hudhaifa continued to do good (invoking Allah to forgive the killer of his father till he met Allah (i.e. died)}}
\hadithdefcmd{bukhari}{3291}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْتِفَاتِ الرَّجُلِ فِي الصَّلاَةِ‏.‏ فَقَالَ ‏ "‏ هُوَ اخْتِلاَسٌ يَخْتَلِسُ الشَّيْطَانُ مِنْ صَلاَةِ أَحَدِكُمْ ‏"‏‏.‏\hadithno{3291}\hadithtrans{Narrated `Aisha:I asked the Prophet (ﷺ) about one's looking here and there during the prayer. He replied, "It is what Satan steals from the prayer of any one of you}}
\hadithdefcmd{bukhari}{3292}{حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ حَدَّثَنِي سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الرُّؤْيَا الصَّالِحَةُ مِنَ اللَّهِ، وَالْحُلُمُ مِنَ الشَّيْطَانِ فَإِذَا حَلَمَ أَحَدُكُمْ حُلُمًا يَخَافُهُ فَلْيَبْصُقْ عَنْ يَسَارِهِ، وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّهَا، فَإِنَّهَا لاَ تَضُرُّهُ ‏"‏‏.‏\hadithno{3292}\hadithtrans{Narrated Abu Qatada:as below. Narrated Abu Qatada: The Prophet (ﷺ) said, "A good dream is from Allah, and a bad or evil dream is from Satan; so if anyone of you has a bad dream of which he gets afraid, he should spit on his left side and should seek Refuge with Allah from its evil, for then it will not harm him}}
\hadithdefcmd{bukhari}{3293}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ‏.‏ فِي يَوْمٍ مِائَةَ مَرَّةٍ، كَانَتْ لَهُ عَدْلَ عَشْرِ رِقَابٍ، وَكُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ، وَمُحِيَتْ عَنْهُ مِائَةُ سَيِّئَةٍ، وَكَانَتْ لَهُ حِرْزًا مِنَ الشَّيْطَانِ يَوْمَهُ ذَلِكَ حَتَّى يُمْسِيَ، وَلَمْ يَأْتِ أَحَدٌ بِأَفْضَلَ مِمَّا جَاءَ بِهِ، إِلاَّ أَحَدٌ عَمِلَ أَكْثَرَ مِنْ ذَلِكَ ‏"‏‏.‏\hadithno{3293}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If one says one-hundred times in one day: "None has the right to be worshipped but Allah, the Alone Who has no partners, to Him belongs Dominion and to Him belong all the Praises, and He has power over all things (i.e. Omnipotent)", one will get the reward of manumitting ten slaves, and one-hundred good deeds will be written in his account, and one-hundred bad deeds will be wiped off or erased from his account, and on that day he will be protected from the morning till evening from Satan, and nobody will be superior to him except one who has done more than that which he has done}}
\hadithdefcmd{bukhari}{3294}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الْحَمِيدِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ، أَنَّ مُحَمَّدَ بْنَ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَخْبَرَهُ أَنَّ أَبَاهُ سَعْدَ بْنَ أَبِي وَقَّاصٍ قَالَ اسْتَأْذَنَ عُمَرُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم، وَعِنْدَهُ نِسَاءٌ مِنْ قُرَيْشٍ يُكَلِّمْنَهُ وَيَسْتَكْثِرْنَهُ، عَالِيَةً أَصْوَاتُهُنَّ، فَلَمَّا اسْتَأْذَنَ عُمَرُ، قُمْنَ يَبْتَدِرْنَ الْحِجَابَ، فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم، وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَضْحَكُ، فَقَالَ عُمَرُ أَضْحَكَ اللَّهُ سِنَّكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ عَجِبْتُ مِنْ هَؤُلاَءِ اللاَّتِي كُنَّ عِنْدِي، فَلَمَّا سَمِعْنَ صَوْتَكَ ابْتَدَرْنَ الْحِجَابَ ‏"‏‏.‏ قَالَ عُمَرُ فَأَنْتَ يَا رَسُولَ اللَّهِ كُنْتَ أَحَقَّ أَنْ يَهَبْنَ‏.‏ ثُمَّ قَالَ أَىْ عَدُوَّاتِ أَنْفُسِهِنَّ، أَتَهَبْنَنِي وَلاَ تَهَبْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْنَ نَعَمْ، أَنْتَ أَفَظُّ وَأَغْلَظُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا لَقِيَكَ الشَّيْطَانُ قَطُّ سَالِكًا فَجًّا إِلاَّ سَلَكَ فَجًّا غَيْرَ فَجِّكَ ‏"‏‏.‏\hadithno{3294}\hadithtrans{Narrated Sa`d bin Abi Waqqas:Once `Umar asked the leave to see Allah's Messenger (ﷺ) in whose company there were some Quraishi women who were talking to him and asking him for more financial support raising their voices. When `Umar asked permission to enter the women got up (quickly) hurrying to screen themselves. When Allah's Messenger (ﷺ) admitted `Umar, Allah's Messenger (ﷺ) was smiling, `Umar asked, "O Allah's Messenger (ﷺ)! May Allah keep you in happiness always." Allah's Messenger (ﷺ) said, "I am astonished at these women who were with me. As soon as they heard your voice, they hastened to screen themselves." `Umar said, "O Allah's Apostle! You have more right to be feared by them." Then he addressed (those women) saying, "O enemies of your own souls! Do you fear me and not Allah's Messenger (ﷺ) ?" They replied. "Yes, for you are a fearful and fierce man as compared with Allah's Messenger (ﷺ)." On that Allah's Messenger (ﷺ) said (to `Umar), "By Him in Whose Hands my life is, whenever Satan sees you taking a path, he follows a path other than yours}}
\hadithdefcmd{bukhari}{3295}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ ـ أُرَاهُ ـ أَحَدُكُمْ مِنْ مَنَامِهِ فَتَوَضَّأَ فَلْيَسْتَنْثِرْ ثَلاَثًا، فَإِنَّ الشَّيْطَانَ يَبِيتُ عَلَى خَيْشُومِهِ ‏"‏‏.‏\hadithno{3295}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If anyone of you rouses from sleep and performs the ablution, he should wash his nose by putting water in it and then blowing it out thrice, because Satan has stayed in the upper part of his nose all the night}}
\hadithdefcmd{bukhari}{3296}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ لَهُ ‏ "‏ إِنِّي أَرَاكَ تُحِبُّ الْغَنَمَ وَالْبَادِيَةَ، فَإِذَا كُنْتَ فِي غَنَمِكَ وَبَادِيَتِكَ فَأَذَّنْتَ بِالصَّلاَةِ، فَارْفَعْ صَوْتَكَ بِالنِّدَاءِ، فَإِنَّهُ لاَ يَسْمَعُ مَدَى صَوْتِ الْمُؤَذِّنِ جِنٌّ وَلاَ إِنْسٌ وَلاَ شَىْءٌ إِلاَّ شَهِدَ لَهُ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3296}\hadithtrans{Narrated `Abdur-Rahman bin `Abdullah bin `Abdur-Rahman bin Abi Sasaa Ansari:That Abu Sa`id Al-Khudri said to his father. "I see you are fond of sheep and the desert, so when you want to pronounce the Adhan, raise your voice with it for whoever will hear the Adhan whether a human being, or a Jinn, or anything else, will bear witness, in favor on the Day of Resurrection." Abu Sa`id added, "I have heard this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3298}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ اقْتُلُوا الْحَيَّاتِ، وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ، فَإِنَّهُمَا يَطْمِسَانِ الْبَصَرَ، وَيَسْتَسْقِطَانِ الْحَبَلَ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ فَبَيْنَا أَنَا أُطَارِدُ، حَيَّةً لأَقْتُلَهَا فَنَادَانِي أَبُو لُبَابَةَ لاَ تَقْتُلْهَا‏.‏ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَ بِقَتْلِ الْحَيَّاتِ‏.‏ قَالَ إِنَّهُ نَهَى بَعْدَ ذَلِكَ عَنْ ذَوَاتِ الْبُيُوتِ، وَهْىَ الْعَوَامِرُ‏.‏\hadithno{3298}\hadithtrans{Narrated Ibn `Umar:That he heard the Prophet (ﷺ) delivering a sermon on the pulpit saying, "Kill snakes and kill Dhu-at- Tufyatain (i.e. a snake with two white lines on its back) and Al-Abtar (i.e. a snake with short or mutilated tail) for they destroy the sight of one's eyes and bring about abortion." (`Abdullah bin `Umar further added): Once while I was chasing a snake in order, to kill it, Abu Lubaba called me saying: "Don't kill it," I said. "Allah's Messenger (ﷺ) ordered us to kill snakes." He said, "But later on he prohibited the killing of snakes living in the houses." (Az-Zuhri said. "Such snakes are called Al-Awamir)}}
\hadithdefcmd{bukhari}{3299}{وَقَالَ عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ، فَرَآنِي أَبُو لُبَابَةَ أَوْ زَيْدُ بْنُ الْخَطَّابِ‏.‏ وَتَابَعَهُ يُونُسُ وَابْنُ عُيَيْنَةَ وَإِسْحَاقُ الْكَلْبِيُّ وَالزُّبَيْدِيُّ‏.‏ وَقَالَ صَالِحٌ وَابْنُ أَبِي حَفْصَةَ وَابْنُ مُجَمِّعٍ عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، رَآنِي أَبُو لُبَابَةَ وَزَيْدُ بْنُ الْخَطَّابِ‏.‏\hadithno{3299}\hadithtrans{Narrated Ibn 'Umar (ra):Abu Lubaba and Zaid bin Khattab saw me}}
\hadithdefcmd{bukhari}{3300}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ أَنْ يَكُونَ خَيْرَ مَالِ الرَّجُلِ غَنَمٌ يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ، يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏‏.‏\hadithno{3300}\hadithtrans{Narrated Abu Sa`id al-Khudri:Allah's Messenger (ﷺ) said, "There will come a time when the best property of a man will be sheep which he will graze on the tops of mountains and the places where rain falls (i.e. pastures) escaping to protect his religion from afflictions}}
\hadithdefcmd{bukhari}{3301}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَأْسُ الْكُفْرِ نَحْوَ الْمَشْرِقِ، وَالْفَخْرُ وَالْخُيَلاَءُ فِي أَهْلِ الْخَيْلِ وَالإِبِلِ، وَالْفَدَّادِينَ أَهْلِ الْوَبَرِ، وَالسَّكِينَةُ فِي أَهْلِ الْغَنَمِ ‏"‏‏.‏\hadithno{3301}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The main source of disbelief is in the east. Pride and arrogance are characteristics of the owners of horses and camels, and those bedouins who are busy with their camels and pay no attention to Religion; while modesty and gentleness are the characteristics of the owners of sheep}}
\hadithdefcmd{bukhari}{3302}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنْ عُقْبَةَ بْنِ عَمْرٍو أَبِي مَسْعُودٍ، قَالَ أَشَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ نَحْوَ الْيَمَنِ فَقَالَ ‏ "‏ الإِيمَانُ يَمَانٍ هَا هُنَا، أَلاَ إِنَّ الْقَسْوَةَ وَغِلَظَ الْقُلُوبِ فِي الْفَدَّادِينَ عِنْدَ أُصُولِ أَذْنَابِ الإِبِلِ، حَيْثُ يَطْلُعُ قَرْنَا الشَّيْطَانِ فِي رَبِيعَةَ وَمُضَرَ ‏"‏‏.‏\hadithno{3302}\hadithtrans{Narrated `Uqba bin `Umar and Abu Mas`ud:Allah's Messenger (ﷺ) pointed with his hand towards Yemen and said, "(True) Belief is Yemenite, towards here (i.e. the Yemenites had True Belief and embraced Islam readily). Certainly sternness and mercilessness are the qualities of those who are loud and at the base of the tails of camels, where the two horns of Satan will appear. Such qualities belong to the tribes of Rabi`a and Mudar}}
\hadithdefcmd{bukhari}{3303}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ صِيَاحَ الدِّيَكَةِ فَاسْأَلُوا اللَّهَ مِنْ فَضْلِهِ، فَإِنَّهَا رَأَتْ مَلَكًا، وَإِذَا سَمِعْتُمْ نَهِيقَ الْحِمَارِ فَتَعَوَّذُوا بِاللَّهِ مِنَ الشَّيْطَانِ، فَإِنَّهُ رَأَى شَيْطَانًا ‏"‏‏.‏\hadithno{3303}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When you hear the crowing of roosters, ask for Allah's Blessings for (their crowing indicates that) they have seen an angel. And when you hear the braying of donkeys, seek Refuge with Allah from Satan for (their braying indicates) that they have seen a Satan}}
\hadithdefcmd{bukhari}{3304}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا رَوْحٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا كَانَ جُنْحُ اللَّيْلِ ـ أَوْ أَمْسَيْتُمْ ـ فَكُفُّوا صِبْيَانَكُمْ، فَإِنَّ الشَّيَاطِينَ تَنْتَشِرُ حِينَئِذٍ، فَإِذَا ذَهَبَ سَاعَةٌ مِنَ اللَّيْلِ فَحُلُّوهُمْ، وَأَغْلِقُوا الأَبْوَابَ، وَاذْكُرُوا اسْمَ اللَّهِ، فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ بَابًا مُغْلَقًا ‏"‏‏.��� قَالَ وَأَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ نَحْوَ مَا أَخْبَرَنِي عَطَاءٌ وَلَمْ يَذْكُرْ ‏"‏ وَاذْكُرُوا اسْمَ اللَّهِ ‏"‏‏.‏\hadithno{3304}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "When night falls (or it is evening), keep your children close to you for the devils spread out at that time. But when an hour of the night elapses, you can let them free. Close the doors and mention the Name of Allah, for Satan does not open a closed door}}
\hadithdefcmd{bukhari}{3305}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فُقِدَتْ أُمَّةٌ مِنْ بَنِي إِسْرَائِيلَ لاَ يُدْرَى مَا فَعَلَتْ، وَإِنِّي لاَ أُرَاهَا إِلاَّ الْفَارَ إِذَا وُضِعَ لَهَا أَلْبَانُ الإِبِلِ لَمْ تَشْرَبْ، وَإِذَا وُضِعَ لَهَا أَلْبَانُ الشَّاءِ شَرِبَتْ ‏"‏‏.‏ فَحَدَّثْتُ كَعْبًا فَقَالَ أَنْتَ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَقُولُهُ قُلْتُ نَعَمْ‏.‏ قَالَ لِي مِرَارًا‏.‏ فَقُلْتُ أَفَأَقْرَأُ التَّوْرَاةَ\hadithno{3305}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A group of Israelites were lost. Nobody knows what they did. But I do not see them except that they were cursed and changed into rats, for if you put the milk of a she-camel in front of a rat, it will not drink it, but if the milk of a sheep is put in front of it, it will drink it." I told this to Ka`b who asked me, "Did you hear it from the Prophet (ﷺ) ?" I said, "Yes." Ka`b asked me the same question several times.; I said to Ka`b. "Do I read the Torah? (i.e. I tell you this from the Prophet)}}
\hadithdefcmd{bukhari}{3306}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، يُحَدِّثُ عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِلْوَزَغِ الْفُوَيْسِقُ‏.‏ وَلَمْ أَسْمَعْهُ أَمَرَ بِقَتْلِهِ‏.‏ وَزَعَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِقَتْلِهِ‏.‏\hadithno{3306}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) called the Salamander, a mischief-doer. I have not heard him ordering that it should be killed. Sa`d bin Abi Waqqas claims that the Prophet (ﷺ) ordered that it should be killed}}
\hadithdefcmd{bukhari}{3307}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جُبَيْرِ بْنِ شَيْبَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أُمَّ شَرِيكٍ، أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهَا بِقَتْلِ الأَوْزَاغِ‏.‏\hadithno{3307}\hadithtrans{Narrated Um Sharik:That the Prophet (ﷺ) ordered her to kill Salamanders}}
\hadithdefcmd{bukhari}{3308}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اقْتُلُوا ذَا الطُّفْيَتَيْنِ، فَإِنَّهُ يَلْتَمِسُ الْبَصَرَ، وَيُصِيبُ الْحَبَلَ ‏"‏‏.‏ تَابَعَهُ حَمَّادُ بْنُ سَلَمَةَ أَبَا أُسَامَةَ\hadithno{3308}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Kill the snake with two white lines on its back, for it blinds the on-looker and causes abortion}}
\hadithdefcmd{bukhari}{3309}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ،، قَالَتْ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَتْلِ الأَبْتَرِ وَقَالَ ‏ "‏ إِنَّهُ يُصِيبُ الْبَصَرَ، وَيُذْهِبُ الْحَبَلَ ‏"‏‏.‏\hadithno{3309}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) ordered that a short-tailed or mutilated-tailed snake (i.e. Abtar) should be killed, for it blinds the on-looker and causes abortion}}
\hadithdefcmd{bukhari}{3311}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ أَبِي يُونُسَ الْقُشَيْرِيِّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقْتُلُ الْحَيَّاتِ ثُمَّ نَهَى قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم هَدَمَ حَائِطًا لَهُ، فَوَجَدَ فِيهِ سِلْخَ حَيَّةٍ فَقَالَ ‏"‏ انْظُرُوا أَيْنَ هُوَ ‏"‏‏.‏ فَنَظَرُوا فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏‏.‏ فَكُنْتُ أَقْتُلُهَا لِذَلِكَ‏.‏ فَلَقِيتُ أَبَا لُبَابَةَ فَأَخْبَرَنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقْتُلُوا الْجِنَّانَ، إِلاَّ كُلَّ أَبْتَرَ ذِي طُفْيَتَيْنِ، فَإِنَّهُ يُسْقِطُ الْوَلَدَ، وَيُذْهِبُ الْبَصَرَ، فَاقْتُلُوهُ ‏"‏‏.‏\hadithno{3311}\hadithtrans{Narrated Abu Mulaika:Ibn `Umar used to kill snakes, but afterwards he forbade their killing and said, "Once the Prophet (ﷺ) pulled down a wall and saw a cast-off skin of a snake in it. He said, 'Look for the snake. 'They found it and the Prophet (ﷺ) said, "Kill it." For this reason I used to kill snakes. Later on I met Abu Lubaba who told me the Prophet (ﷺ) said, 'Do not kill snakes except the short-tailed or mutilated-tailed snake with two white lines on its back, for it causes abortion and makes one blind. So kill it}}
\hadithdefcmd{bukhari}{3313}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يَقْتُلُ الْحَيَّاتِ‏.‏ فَحَدَّثَهُ أَبُو لُبَابَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ جِنَّانِ الْبُيُوتِ، فَأَمْسَكَ عَنْهَا‏.‏\hadithno{3313}\hadithtrans{Narrated Nafi`:Ibn `Umar used to kill snakes but when Abu Lubaba informed him that the Prophet (ﷺ) had forbidden the killing of snakes living in houses, he gave up killing them}}
\hadithdefcmd{bukhari}{3314}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عَنْهَا ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ فَوَاسِقُ يُقْتَلْنَ فِي الْحَرَمِ الْفَأْرَةُ، وَالْعَقْرَبُ، وَالْحُدَيَّا، وَالْغُرَابُ، وَالْكَلْبُ الْعَقُورُ ‏"‏‏.‏\hadithno{3314}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Five kinds of animals are mischief-doers and can be killed even in the Sanctuary: They are the rat the scorpion, the kite (a type of predatory bird), the crow and the rabid dog}}
\hadithdefcmd{bukhari}{3315}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَمْسٌ مِنَ الدَّوَابِّ مَنْ قَتَلَهُنَّ وَهْوَ مُحْرِمٌ فَلاَ جُنَاحَ عَلَيْهِ الْعَقْرَبُ، وَالْفَأْرَةُ، وَالْكَلْبُ الْعَقُورُ، وَالْغُرَابُ، وَالْحِدَأَةُ ‏"‏‏.‏\hadithno{3315}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "It is not sinful of a person in the state of Ihram to kill any of these five animals: The scorpion, the rat, the rabid dog, the crow and the kite}}
\hadithdefcmd{bukhari}{3316}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ كَثِيرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ رَفَعَهُ قَالَ ‏ "‏ خَمِّرُوا الآنِيَةَ، وَأَوْكُوا الأَسْقِيَةَ، وَأَجِيفُوا الأَبْوَابَ، وَاكْفِتُوا صِبْيَانَكُمْ عِنْدَ الْعِشَاءِ، فَإِنَّ لِلْجِنِّ انْتِشَارًا وَخَطْفَةً، وَأَطْفِئُوا الْمَصَابِيحَ عِنْدَ الرُّقَادِ، فَإِنَّ الْفُوَيْسِقَةَ رُبَّمَا اجْتَرَّتِ الْفَتِيلَةَ فَأَحْرَقَتْ أَهْلَ الْبَيْتِ ‏"‏‏.‏ قَالَ ابْنُ جُرَيْجٍ وَحَبِيبٌ عَنْ عَطَاءٍ فَإِنَّ لِلشَّيَاطِينِ‏.‏\hadithno{3316}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Cover your utensils and tie your water skins, and close your doors and keep your children close to you at night, as the Jinns spread out at such time and snatch things away. When you go to bed, put out your lights, for the mischief-doer (i.e. the rat) may drag away the wick of the candle and burn the dwellers of the house." Ata said, "The devils." (instead of the Jinns)}}
\hadithdefcmd{bukhari}{3317}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَارٍ فَنَزَلَتْ ‏\{‏وَالْمُرْسَلاَتِ عُرْفًا‏\}‏ فَإِنَّا لَنَتَلَقَّاهَا مِنْ فِيهِ، إِذْ خَرَجَتْ حَيَّةٌ مِنْ جُحْرِهَا فَابْتَدَرْنَاهَا لِنَقْتُلَهَا، فَسَبَقَتْنَا فَدَخَلَتْ جُحْرَهَا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وُقِيَتْ شَرَّكُمْ، كَمَا وُقِيتُمْ شَرَّهَا ‏"‏‏.‏ وَعَنْ إِسْرَائِيلَ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ عَنْ عَبْدِ اللَّهِ مِثْلَهُ قَالَ وَإِنَّا لَنَتَلَقَّاهَا مِنْ فِيهِ رَطْبَةً‏.‏ وَتَابَعَهُ أَبُو عَوَانَةَ عَنْ مُغِيرَةَ‏.‏ وَقَالَ حَفْصٌ وَأَبُو مُعَاوِيَةَ وَسُلَيْمَانُ بْنُ قَرْمٍ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ عَنِ الأَسْوَدِ عَنْ عَبْدِ اللَّهِ‏.‏\hadithno{3317}\hadithtrans{Narrated `Abdullah:Once we were in the company of Allah's Messenger (ﷺ) in a cave. Surat-al-Mursalat (77) was revealed there, and we were learning it from Allah's Messenger (ﷺ) . Suddenly a snake came out of its hole and we rushed towards it to kill it, but it hastened and entered its hole before we were able to catch it. Allah's Messenger (ﷺ) said," It has been saved from your evil and you have been saved from its evil}}
\hadithdefcmd{bukhari}{3318}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دَخَلَتِ امْرَأَةٌ النَّارَ فِي هِرَّةٍ رَبَطَتْهَا، فَلَمْ تُطْعِمْهَا، وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خِشَاشِ الأَرْضِ ‏"‏‏.‏ قَالَ وَحَدَّثَنَا عُبَيْدُ اللَّهِ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{3318}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "A woman entered the (Hell) Fire because of a cat which she had tied, neither giving it food nor setting it free to eat from the vermin of the earth}}
\hadithdefcmd{bukhari}{3319}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَزَلَ نَبِيٌّ مِنَ الأَنْبِيَاءِ تَحْتَ شَجَرَةٍ فَلَدَغَتْهُ نَمْلَةٌ، فَأَمَرَ بِجَهَازِهِ فَأُخْرِجَ مِنْ تَحْتِهَا، ثُمَّ أَمَرَ بِبَيْتِهَا فَأُحْرِقَ بِالنَّارِ، فَأَوْحَى اللَّهُ إِلَيْهِ فَهَلاَّ نَمْلَةً وَاحِدَةً ‏"‏‏.‏\hadithno{3319}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Once while a prophet amongst the prophets was taking a rest underneath a tree, an ant bit him. He, therefore, ordered that his luggage be taken away from underneath that tree and then ordered that the dwelling place of the ants should be set on fire. Allah sent him a revelation:-- "Wouldn't it have been sufficient to burn a single ant? (that bit you): (See Page 162, chapter No)}}
\hadithdefcmd{bukhari}{3320}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنِي عُتْبَةُ بْنُ مُسْلِمٍ، قَالَ أَخْبَرَنِي عُبَيْدُ بْنُ حُنَيْنٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا وَقَعَ الذُّبَابُ فِي شَرَابِ أَحَدِكُمْ فَلْيَغْمِسْهُ، ثُمَّ لِيَنْزِعْهُ، فَإِنَّ فِي إِحْدَى جَنَاحَيْهِ دَاءً وَالأُخْرَى شِفَاءً ‏"‏‏.‏\hadithno{3320}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said "If a house fly falls in the drink of anyone of you, he should dip it (in the drink) and take it out, for one of its wings has a disease and the other has the cure for the disease}}
\hadithdefcmd{bukhari}{3321}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْحَاقُ الأَزْرَقُ، حَدَّثَنَا عَوْفٌ، عَنِ الْحَسَنِ، وَابْنِ، سِيرِينَ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُفِرَ لاِمْرَأَةٍ مُومِسَةٍ مَرَّتْ بِكَلْبٍ عَلَى رَأْسِ رَكِيٍّ يَلْهَثُ، قَالَ كَادَ يَقْتُلُهُ الْعَطَشُ، فَنَزَعَتْ خُفَّهَا، فَأَوْثَقَتْهُ بِخِمَارِهَا، فَنَزَعَتْ لَهُ مِنَ الْمَاءِ، فَغُفِرَ لَهَا بِذَلِكَ ‏"‏‏.‏\hadithno{3321}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A prostitute was forgiven by Allah, because, passing by a panting dog near a well and seeing that the dog was about to die of thirst, she took off her shoe, and tying it with her head-cover she drew out some water for it. So, Allah forgave her because of that}}
\hadithdefcmd{bukhari}{3322}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْتُهُ مِنَ الزُّهْرِيِّ كَمَا أَنَّكَ هَا هُنَا أَخْبَرَنِي عُبَيْدُ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنْ أَبِي طَلْحَةَ ـ رضى الله عنهم ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةٌ ‏"‏‏.‏\hadithno{3322}\hadithtrans{Narrated Abu Talha:The Prophet (ﷺ) said, "Angels do not enter a house that has either a dog or a picture in it}}
\hadithdefcmd{bukhari}{3323}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ‏.‏\hadithno{3323}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) ordered that the dogs should be killed}}
\hadithdefcmd{bukhari}{3324}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَمْسَكَ كَلْبًا يَنْقُصْ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ، إِلاَّ كَلْبَ حَرْثٍ أَوْ كَلْبَ مَاشِيَةٍ ‏"‏‏.‏\hadithno{3324}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If somebody keeps a dog, he loses one Qirat (of the reward) of his good deeds everyday, except if he keeps it for the purpose of agriculture or for the protection of livestock}}
\hadithdefcmd{bukhari}{3325}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، قَالَ أَخْبَرَنِي يَزِيدُ بْنُ خُصَيْفَةَ، قَالَ أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، سَمِعَ سُفْيَانَ بْنَ أَبِي زُهَيْرٍ الشَّنَئِيَّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا، نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏‏.‏ فَقَالَ السَّائِبُ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِيْ وَرَبِّ هَذِهِ الْقِبْلَةِ‏.‏\hadithno{3325}\hadithtrans{Narrated Sufyan bin Abi Zuhair Ash-Shanai:That he heard Allah's Messenger (ﷺ) saying, "If somebody keeps a dog that is neither used for farm work nor for guarding the livestock, he will lose one Qirat (of the reward) of his good deeds everyday}}
